@@ -32,7 +32,7 @@ require_once 'include/action.php';
 require_once 'include/log.class.php';
 require_once 'include/lib/modalboxhelper.class.php';
 require_once 'include/lib/multimediahelper.class.php';
-require_once 'modules/search/agendaindexer.class.php';
+require_once 'modules/search/lucene/agendaindexer.class.php';
 require_once 'modules/agenda/course_calendar.inc.php';
 ModalBoxHelper::loadModalBox();
 
@@ -289,6 +289,7 @@ if ($is_editor) {
                     $eventID = $id;
                     $startDateEvent = Database::get()->querySingle("SELECT start FROM agenda WHERE course_id = ?d AND id = ?d",$course_id,$id)->start;
                     $startDateEvent = date('Y-m-d',strtotime($startDateEvent));
+                    $recursionEndDate = Database::get()->querySingle("SELECT recursion_end FROM agenda WHERE course_id = ?d AND id = ?d",$course_id,$id)->recursion_end;
 
                     $tool_content .= "
                                 <div class='col-12 calendar-events-container'>
@@ -299,7 +300,7 @@ if ($is_editor) {
                                     </div>
                                 </div>
 
-                                <div id='editAgendaEventModal' class='modal fade in' role='dialog'>
+                                <div id='editAgendaEventModal' class='modal fade in' role='dialog' data-bs-focus='false'>
                                     <form id='agendaform' class='form-horizontal' role='form' method='post' action='$_SERVER[SCRIPT_NAME]?course=$course_code'>
                                         <div class='modal-dialog modal-md'>
                                             <!-- Modal content-->
@@ -312,7 +313,7 @@ if ($is_editor) {
                                                 <div class='modal-body'>
                                                     <div class='form-wrapper form-edit border-0 px-0'>
 
-
+                                                        <input type='hidden' id='recursionEndDate' value='$recursionEndDate'>
                                                         <input type='hidden' id = 'id' name='id' value='$id'>
                                                         <input type='hidden' name='rep' id='rep' value='$applytogroup'>
 
@@ -499,6 +500,19 @@ if ($is_editor) {
                                             duration = hours + ':' + (minutes <= 9 ? '0' : '') + minutes;
                                             $('#editAgendaEventModal #durationcal').val(duration);
                                             $('#editAgendaEventModal').modal('toggle');
+
+                                            var recursionEndDate = $('#recursionEndDate').val();
+                                            if(!recursionEndDate) {
+                                                var endDateValueForm = $('#editAgendaEventModal #startdate').val();
+                                                var parts = endDateValueForm.split(' ');
+                                                var datePart = parts[0];
+                                                var dateParts = datePart.split('-');
+                                                var numberDay = parseInt(dateParts[0], 10);
+                                                var numberMonth = parseInt(dateParts[1], 10) - 1;
+                                                var numberYear = parseInt(dateParts[2], 10);
+                                                var endDateEventVal = new Date(numberYear, numberMonth, numberDay);
+                                                $('#enddate').datepicker('setDate', endDateEventVal);            
+                                            }
                                         }else{
                                             alert('$langChooseDayAgain');
                                             window.location.reload();
@@ -590,7 +604,7 @@ if ($is_editor) {
                     </div>
                 </div>
 
-                <div id='createAgendaEventModal' class='modal fade in' role='dialog'>
+                <div id='createAgendaEventModal' class='modal fade in' role='dialog' data-bs-focus='false'>
                     <form id='agendaform' class='form-horizontal' role='form' method='post' action='$_SERVER[SCRIPT_NAME]?course=$course_code'>
                         <div class='modal-dialog modal-md'>
 
@@ -777,6 +791,16 @@ if ($is_editor) {
 
                                     $('#createAgendaEventModal').modal('toggle');
 
+                                    var endDateValueForm = $('#createAgendaEventModal #enddateEvent').val();
+                                    var parts = endDateValueForm.split(' ');
+                                    var datePart = parts[0];
+                                    var dateParts = datePart.split('-');
+                                    var numberDay = parseInt(dateParts[0], 10);
+                                    var numberMonth = parseInt(dateParts[1], 10) - 1;
+                                    var numberYear = parseInt(dateParts[2], 10);
+                                    var endDateEventVal = new Date(numberYear, numberMonth, numberDay);
+                                    $('#enddate').datepicker('setDate', endDateEventVal);
+
                                 }else{
                                     alert('$langChooseDayAgain');
                                     window.location.reload();
