@@ -239,7 +239,8 @@ function display_attendance_activities($attendance_id) {
            $langHere, $langAttendanceNoActMessage3, $langAttendanceActivity,
            $langConfig, $langStudents, $langGradebookAddActivity, $langInsertWorkCap, $langExercise,
            $langAdd, $langExport, $langBack, $langNoStudentsInAttendance, $langBBB,
-           $is_editor, $is_course_reviewer, $is_collaborative_course, $langSettingSelect;
+           $is_editor, $is_course_reviewer, $is_collaborative_course, $langSettingSelect,
+           $langQRCodePresence;
 
     $attendance_id_ind = getIndirectReference($attendance_id);
     if ($is_editor) {
@@ -366,6 +367,11 @@ function display_attendance_activities($attendance_id) {
                             'icon' => 'fa-edit',
                             'url' => "$_SERVER[SCRIPT_NAME]?course=$course_code&amp;attendance_id=$attendance_id&amp;modify=" . getIndirectReference($details->id)
                         ),
+                        array('title' => $langQRCodePresence,
+                            'icon' => 'fa-solid fa-qrcode',
+                            'url' => "$_SERVER[SCRIPT_NAME]?course=$course_code&amp;attendance_id=$attendance_id&amp;gen_qrcodePr=true&amp;actId=" . getIndirectReference($details->id),
+                            'show' => !$details->module_auto_id
+                        ),
                         array('title' => $langDelete,
                             'icon' => 'fa-xmark',
                             'url' => "$_SERVER[SCRIPT_NAME]?course=$course_code&amp;&amp;attendance_id=$attendance_id&amp;delete=" . getIndirectReference($details->id),
@@ -426,7 +432,7 @@ function attendance_display_available_assignments($attendance_id) {
 
     global $course_id, $course_code, $tool_content, $urlServer,
            $m, $langDescription, $langAttendanceNoActMessageAss4,
-           $langAdd, $langTitle, $langSettingSelect;
+           $langAdd, $langTitle, $langSettingSelect, $langWorkAssignTo;
 
     $checkForAss = Database::get()->queryArray("SELECT * FROM assignment WHERE assignment.course_id = ?d
                                                 AND assignment.active = 1
@@ -445,7 +451,7 @@ function attendance_display_available_assignments($attendance_id) {
         foreach ($checkForAss as $newAssToGradebook) {
             $content = ellipsize_html($newAssToGradebook->description, 50);
             if ($newAssToGradebook->assign_to_specific) {
-                $content .= "$m[WorkAssignTo]:<br>";
+                $content .= "$langWorkAssignTo:<br>";
                 $checkForAssSpec = Database::get()->queryArray("SELECT user_id, user.surname, user.givenname
                                                     FROM `assignment_to_specific`, user
                                                     WHERE user_id = user.id AND assignment_id = ?d", $newAssToGradebook->id);
@@ -600,7 +606,7 @@ function add_attendance_other_activity($attendance_id) {
                         ),
                         array(
                             'class' => 'cancelAdminBtn ms-1',
-                            'href' => "$_SERVER[SCRIPT_NAME]?course=$course_code"
+                            'href' => "$_SERVER[SCRIPT_NAME]?course=$course_code&amp;attendance_id={$attendance_id}"
                         )
                     ))."</div></div>";
                     if (isset($_GET['modify'])) {
@@ -757,19 +763,14 @@ function update_user_attendance_activities($attendance_id, $uid) {
 }
 
 /**
- * @brief create new attendance
- * @global string $tool_content
- * @global type $course_code
- * @global type $langNewAttendance2
- * @global type $langTitle
- * @global type $langSave
- * @global type $langInsert
+ * @brief Display attendance book form
+ * @param type $attendance_id
  */
-function new_attendance() {
+function attendance_book_form($attendance_id = null) {
 
-    global $tool_content, $course_code, $langNewAttendance2, $head_content,
-           $langTitle, $langSave, $langInsert, $langAttendanceLimitNumber,
-           $attendance_limit, $langStart, $langEnd, $language, $langImgFormsDes;
+    global  $tool_content, $course_code, $head_content, $langTitle, $langSubmit,
+            $langInsert, $langAttendanceLimitNumber, $langStart,
+            $langEnd, $language, $langImgFormsDes, $langAttendanceUpdate, $attendance;
 
     load_js('bootstrap-datetimepicker');
     $head_content .= "
@@ -783,78 +784,86 @@ function new_attendance() {
             });
         });
     </script>";
+
+    // Create new attendance book
+    if ($attendance_id === null) {
+        $title_default = '';
+        $start_date_default = '';
+        $end_date_default = '';
+        $limit_default = '';
+
+        $action = "$_SERVER[SCRIPT_NAME]?course=$course_code";
+    } else { // Edit attendance book
+        $title_default = $attendance->title;
+        $start_date_default = DateTime::createFromFormat('Y-m-d H:i:s', $attendance->start_date)->format('d-m-Y H:i');
+        $end_date_default = DateTime::createFromFormat('Y-m-d H:i:s', $attendance->end_date)->format('d-m-Y H:i');
+        $limit_default = get_attendance_limit($attendance_id);
+
+        $action = "$_SERVER[SCRIPT_NAME]?course=$course_code&attendance_id=$attendance_id";
+    }
+
     $title_error = Session::getError('title');
-    $title = Session::has('title') ? Session::get('title') : '';
+    $title = Session::has('title') ? Session::get('title') : $title_default;
     $start_date_error = Session::getError('start_date');
-    $start_date = Session::has('start_date') ? Session::get('start_date') : '';
+    $start_date = Session::has('start_date') ? Session::get('start_date') : $start_date_default;
     $end_date_error = Session::getError('end_date');
-    $end_date = Session::has('end_date') ? Session::get('end_date') : '';
+    $end_date = Session::has('end_date') ? Session::get('end_date') : $end_date_default;
+
     $limit_error  = Session::getError('limit');
-    $limit = Session::has('limit') ? Session::get('limit') : '';
+    $limit = Session::has('limit') ? Session::get('limit') : $limit_default;
 
     $tool_content .= "
-    <div class='d-lg-flex gap-4 mt-4'>  
+    <div class='d-lg-flex gap-4 mt-4'>
         <div class='flex-grow-1'>
             <div class='form-wrapper form-edit rounded border-0 px-0'>
-                <form class='form-horizontal' role='form' method='post' action='$_SERVER[SCRIPT_NAME]?course=$course_code' onsubmit=\"return checkrequired(this, 'antitle');\">
-                    <div class='form-group'>
-                    <label for='titleID' class='col-12 control-label-notes'>$langNewAttendance2 <span class='asterisk Accent-200-cl'>(*)</span></label></div>
+                <form class='form-horizontal' role='form' method='post' action=$action>
                     <div class='form-group".($title_error ? " has-error" : "")."'>
+                        <label for='title_id' class='col-12 control-label-notes'>$langTitle <span class='asterisk Accent-200-cl'>(*)</span></label>
                         <div class='col-12'>
-                            <input id='titleID' class='form-control' type='text' placeholder='$langTitle' name='title'>
+                            <input id='title_id' class='form-control' type='text' placeholder='$langTitle' name='title' value='".q($title)."'>
                             <span class='help-block Accent-200-cl'>$title_error</span>
                         </div>
                     </div>
-                   
-                        
-                            <div class='form-group mt-4".($start_date_error ? " has-error" : "")."'>
-                                <div class='col-12'>
-                                    <label for='start_date' class='control-label-notes'>$langStart <span class='asterisk Accent-200-cl'>(*)</span></label>
-                                </div>
-                                <div class='col-12'>
-                                    <input class='form-control' placeholder='$langStart' type='text' name='start_date' id='start_date' value='$start_date'>
-                                    <span class='help-block Accent-200-cl'>$start_date_error</span>
-                                </div>
-                            </div>
-                        
-                      
-                            <div class='form-group mt-4".($end_date_error ? " has-error" : "")."'>
-                                <div class='col-12'>
-                                    <label for='end_date' class='control-label-notes'>$langEnd <span class='asterisk Accent-200-cl'>(*)</span></label>
-                                </div>
-                                <div class='col-12'>
-                                    <input class='form-control' placeholder='$langEnd' type='text' name='end_date' id='end_date' value='$end_date'>
-                                    <span class='help-block Accent-200-cl'>$end_date_error</span>
-                                </div>
-                            </div>
-                       
-                   
+                    <div class='form-group mt-4".($start_date_error ? " has-error" : "")."'>
+                        <div class='col-12'>
+                            <label for='start_date' class='control-label-notes'>$langStart <span class='asterisk Accent-200-cl'>(*)</span></label>
+                        </div>
+                        <div class='col-12'>
+                            <input class='form-control' placeholder='$langStart' type='text' name='start_date' id='start_date' value='".q($start_date)."'>
+                            <span class='help-block Accent-200-cl'>$start_date_error</span>
+                        </div>
+                    </div>
+                    <div class='form-group mt-4".($end_date_error ? " has-error" : "")."'>
+                        <div class='col-12'>
+                            <label for='end_date' class='control-label-notes'>$langEnd <span class='asterisk Accent-200-cl'>(*)</span></label>
+                        </div>
+                        <div class='col-12'>
+                            <input class='form-control' placeholder='$langEnd' type='text' name='end_date' id='end_date' value='".q($end_date)."'>
+                            <span class='help-block Accent-200-cl'>$end_date_error</span>
+                        </div>
+                    </div>
                     <div class='form-group mt-4".($limit_error ? " has-error" : "")."'>
                         <label for='limit_id' class='col-12 control-label-notes'>$langAttendanceLimitNumber <span class='asterisk Accent-200-cl'>(*)</span></label>
                         <div class='col-sm-12'>
-                            <input id='limit_id' class='form-control' placeholder='$langAttendanceLimitNumber' type='text' name='limit' value='$attendance_limit'>
+                            <input id='limit_id' class='form-control' placeholder='$langAttendanceLimitNumber' type='text' name='limit' value='".q($limit)."'>
                             <span class='help-block Accent-200-cl'>$limit_error</span>
                         </div>
                     </div>
                     <div class='form-group mt-5 d-flex justify-content-end align-items-center'>
-                        "
-
-                                    .form_buttons(array(
-                                        array(
-                                                'class'=> 'submitAdminBtn',
-                                                'text' => $langSave,
-                                                'name' => 'newAttendance',
-                                                'value'=> $langInsert
-                                        ),
-                                            array(
-                                                'class'=> 'cancelAdminBtn ms-1',
-                                                'href' => "$_SERVER[SCRIPT_NAME]?course=$course_code"
-                                                )
-                                        )).
-
-
-
-                        "
+                        " . form_buttons(
+                                array(
+                                    array(
+                                        'class' => 'submitAdminBtn',
+                                        'text' => $langSubmit,
+                                        'name' => $attendance_id === null ? 'attendanceBookCreate' : 'attendanceBookSettings',
+                                        'value'=> $attendance_id === null ? $langInsert : $langAttendanceUpdate
+                                    ),
+                                    array(
+                                        'class' => 'cancelAdminBtn ms-1',
+                                        'href' => "$_SERVER[SCRIPT_NAME]?course=$course_code"
+                                    )
+                                )
+                            )."
                     </div>
                 </form>
             </div>
@@ -864,7 +873,6 @@ function new_attendance() {
         </div>
     </div>";
 }
-
 /**
  * @brief display user presences
  * @param int $attendance_id
@@ -1047,112 +1055,6 @@ function display_all_users_presences($attendance_id) {
     }
 }
 
-/**
- * @brief insert/modify attendance settings
- * @param int $attendance_id
- */
-function attendance_settings($attendance_id) {
-
-    global $tool_content, $course_code, $language,
-           $langTitle, $langAttendanceLimitNumber,
-           $langAttendanceUpdate, $langSave, $head_content,
-           $attendance, $langStart, $langEnd, $langImgFormsDes;
-
-    load_js('bootstrap-datetimepicker');
-    $head_content .= "
-    <script type='text/javascript'>
-        $(function() {
-            $('#start_date, #end_date').datetimepicker({
-                format: 'dd-mm-yyyy hh:ii',
-                pickerPosition: 'bottom-right',
-                language: '".$language."',
-                autoclose: true
-            });
-        });
-    </script>";
-    $title_error = Session::getError('title');
-    $title = Session::has('title') ? Session::get('title') : $attendance->title;
-    $start_date_error = Session::getError('start_date');
-    $start_date = Session::has('start_date') ? Session::get('start_date') : DateTime::createFromFormat('Y-m-d H:i:s', $attendance->start_date)->format('d-m-Y H:i');
-    $end_date_error = Session::getError('end_date');
-    $end_date = Session::has('end_date') ? Session::get('end_date') : DateTime::createFromFormat('Y-m-d H:i:s', $attendance->end_date)->format('d-m-Y H:i');
-    $limit_error  = Session::getError('limit');
-    $limit = Session::has('limit') ? Session::get('limit') : get_attendance_limit($attendance_id);
-    // update attendance title
-    $tool_content .= "
-
-    <div class='d-lg-flex gap-4 mt-4'>
-        <div class='flex-grow-1'>
-            <div class='form-wrapper form-edit rounded border-0 px-0'>
-                <form class='form-horizontal' role='form' method='post' action='$_SERVER[SCRIPT_NAME]?course=$course_code&attendance_id=$attendance_id'>
-                    <div class='form-group".($title_error ? " has-error" : "")."'>
-                        <label for='title_id' class='col-12 control-label-notes'>$langTitle <span class='asterisk Accent-200-cl'>(*)</span></label>
-                        <div class='col-12'>
-                            <input id='title_id' class='form-control' type='text' placeholder='$langTitle' name='title' value='".q($title)."'>
-                            <span class='help-block Accent-200-cl'>$title_error</span>
-                        </div>
-                    </div>
-                    
-                       
-                            <div class='form-group".($start_date_error ? " has-error" : "")." mt-4'>
-                                <div class='col-12'>
-                                    <label for='start_date' class='control-label-notes'>$langStart <span class='asterisk Accent-200-cl'>(*)</span></label>
-                                </div>
-                                <div class='col-12'>
-                                    <input class='form-control' type='text' name='start_date' id='start_date' value='$start_date'>
-                                    <span class='help-block Accent-200-cl'>$start_date_error</span>
-                                </div>
-                            </div>
-                        
-                       
-                            <div class='form-group".($end_date_error ? " has-error" : "")." mt-4'>
-                                <div class='col-12'>
-                                    <label for='end_date' class='control-label-notes'>$langEnd <span class='asterisk Accent-200-cl'>(*)</span></label>
-                                </div>
-                                <div class='col-12'>
-                                    <input class='form-control' type='text' name='end_date' id='end_date' value='$end_date'>
-                                    <span class='help-block Accent-200-cl'>$end_date_error</span>
-                                </div>
-                            </div>
-                        
-                    
-                    <div class='form-group".($limit_error ? " has-error" : "")." mt-4'>
-                        <label for='limitId' class='col-12 control-label-notes'>$langAttendanceLimitNumber <span class='asterisk Accent-200-cl'>(*)</span></label>
-                        <div class='col-sm-12'>
-                            <input id='limitId' class='form-control' type='text' name='limit' value='$limit'/>
-                            <span class='help-block Accent-200-cl'>$limit_error</span>
-                        </div>
-                    </div>
-                    <div class='form-group mt-5 d-flex justify-content-end align-items-center'>
-
-
-
-                                 ".form_buttons(array(
-                                    array(
-                                        'class' => 'submitAdminBtn',
-                                        'text' => $langSave,
-                                        'name' => 'submitAttendanceBookSettings',
-                                        'value'=> $langAttendanceUpdate
-                                    ),
-                                    array(
-                                        'class' => 'cancelAdminBtn ms-1',
-                                        'href' => "$_SERVER[SCRIPT_NAME]?course=$course_code&amp;attendance_id=$attendance_id"
-                                    )
-                                ))."
-
-
-
-
-                    </div>
-                    </fieldset>
-                </form>
-            </div>
-        </div>
-        <div class='d-none d-lg-block'>
-            <img class='form-image-modules' src='".get_form_image()."' alt='$langImgFormsDes'>
-        </div>
-    </div>";
-}
 
 /**
  * @brief modify user attendance settings
@@ -1351,7 +1253,7 @@ function student_view_attendance($attendance_id) {
             }
 
             $tool_content .= "</td>"
-                    . "<td><div class='smaller'>" . format_locale_date(strtotime($details->date), 'short', false) . "</div></td>"
+                    . "<td><div class='smaller'>" . (is_null($details->date) ? '' : format_locale_date(strtotime($details->date), 'short', false)) . "</div></td>"
                     . "<td>" . $content . "</td>";
             $tool_content .= "<td class='text-center'>";
             //check user grade for this activity
@@ -1638,6 +1540,7 @@ function import_attendances($attendance_id, $activity, $import = false) {
            $langImgFormsDes, $langForm;
 
     if ($import and isset($_FILES['userfile'])) { // import user attendances
+        if (!isset($_POST['token']) || !validate_csrf_token($_POST['token'])) csrf_token_error();
         $file = IOFactory::load($_FILES['userfile']['tmp_name']);
         $sheet = $file->getActiveSheet();
         $userAttendance = $errorLines = $invalidUsers = $extraUsers = [];
@@ -1758,6 +1661,7 @@ function import_attendances($attendance_id, $activity, $import = false) {
                                     </div>
                                 </div>
                             </fieldset>
+                            " . generate_csrf_token_form_field() . "
                         </form>
                     </div>
                 </div><div class='d-none d-lg-block'>
