@@ -18,13 +18,22 @@
  *
  */
 
+use BaconQrCode\Renderer\ImageRenderer;
+use BaconQrCode\Renderer\Image\SvgImageBackEnd;
+use BaconQrCode\Renderer\RendererStyle\RendererStyle;
+use BaconQrCode\Writer;
+
 $require_login = true;
 $require_current_course = true;
 $require_user_registration = true;
 $require_help = true;
 $helpTopic = 'attendance';
 
-require_once '../../include/baseTheme.php';
+if (isset($_GET['qrCode_presence'])) {
+    require_once '../../include/init.php';
+} else {
+    require_once '../../include/baseTheme.php';
+}
 require_once 'functions.php';
 require_once 'include/log.class.php';
 
@@ -73,11 +82,8 @@ if ($is_editor) {
 <script type='text/javascript'>
 $(function() {
     var oTable = $('#users_table{$course_id}').DataTable ({
-                'columns': [ $columns ],
-                'aLengthMenu': [
-                   [10, 15, 20 , -1],
-                   [10, 15, 20, '$langAllOfThem'] // change per page values here
-               ],
+               'columns': [ $columns ],
+               'lengthMenu': [10, 15, 20 , -1],
                'fnDrawCallback': function( oSettings ) {
                     $('#users_table{$course_id}_wrapper label input[type=search]').attr({
                       'class' : 'form-control input-sm ms-0 mb-3',
@@ -89,10 +95,11 @@ $(function() {
                 'bSort': true,
                 'searchDelay': 1000,
                 'oLanguage': {
+                       'lengthLabels': {'-1': '$langAllOfThem'},
                        'sLengthMenu':   '$langDisplay _MENU_ $langResults2',
                        'sZeroRecords':  '".$langNoResult."',
                        'sInfo':         '$langDisplayed _START_ $langTill _END_ $langFrom2 _TOTAL_ $langTotalResults',
-                       'sInfoEmpty':    '$langDisplayed 0 $langTill 0 $langFrom2 0 $langResults2',
+                       'sInfoEmpty':    '',
                        'sInfoFiltered': '',
                        'sInfoPostFix':  '',
                        'sSearch':       '',
@@ -147,15 +154,15 @@ $('input[id=button_groups]').click(changeAssignLabel);
             var select_content_2 = '';
             if (type==2) {
                 for (index = 0; index < parsed_data.length; ++index) {
-                    select_content += '<option value=\"' + parsed_data[index]['id'] + '\">' + parsed_data[index]['name'] + '<\/option>';
+                    select_content += '<option value=\"' + parsed_data[index]['id'] + '\">' + q(parsed_data[index]['name']) + '<\/option>';
                 }
             }
             if (type==1) {
                 for (index = 0; index < parsed_data[0].length; ++index) {
-                    select_content += '<option value=\"' + parsed_data[0][index]['id'] + '\">' + parsed_data[0][index]['surname'] + ' ' + parsed_data[0][index]['givenname'] + '<\/option>';
+                    select_content += '<option value=\"' + parsed_data[0][index]['id'] + '\">' + q(parsed_data[0][index]['surname'] + ' ' + parsed_data[0][index]['givenname']) + '<\/option>';
                 }
                 for (index = 0; index < parsed_data[1].length; ++index) {
-                    select_content_2 += '<option value=\"' + parsed_data[1][index]['id'] + '\">' + parsed_data[1][index]['surname'] + ' ' + parsed_data[1][index]['givenname'] + '<\/option>';
+                    select_content_2 += '<option value=\"' + parsed_data[1][index]['id'] + '\">' + q(parsed_data[1][index]['surname'] + ' ' + parsed_data[1][index]['givenname']) + '<\/option>';
                 }
             }
             $('#users_box').find('option').remove().end().append(select_content);
@@ -175,8 +182,160 @@ if (isset($_REQUEST['attendance_id'])) {
     $pageName = $langEditChange;
 }
 
+if (isset($_GET['qrCode_presence'])) {
+    $attendance_id = $_REQUEST['attendance_id'];
+    $activeUser = Database::get()->querySingle("SELECT id,`uid` FROM attendance_users WHERE attendance_id = ?d AND `uid` = ?d", $attendance_id, $uid);
+    $activeAttendance = false;
+    $q_activeAttendance = Database::get()->querySingle("SELECT start_date, end_date FROM attendance WHERE id = ?d", $attendance_id);
+    $now = new DateTime();
+    if ($q_activeAttendance->start_date < $now->format('Y-m-d H:i:s') and $q_activeAttendance->end_date > $now->format('Y-m-d H:i:s')) {
+        $activeAttendance = true;
+    }
+    if ($activeUser && $activeAttendance) {
+        $userID = $activeUser->uid;
+        $actID = intval($_GET['actId']);
+        $attend = 1;
+        $checkForBook = Database::get()->querySingle("SELECT id, attend FROM attendance_book WHERE attendance_activity_id = ?d AND `uid` = ?d", $actID, $userID);
+        if ($checkForBook) {
+            if ($checkForBook->attend != $attend) {
+                Database::get()->query("UPDATE attendance_book SET attend = ?d WHERE id = ?d", $attend, $checkForBook->id);
+            }
+        } else {
+            Database::get()->query("INSERT INTO attendance_book SET `uid` = ?d, attendance_activity_id = ?d, attend = ?d, comments = ''", $userID, $actID, $attend);
+        }
+        triggerAttendanceGame($course_id, $userID, $attendance_id, AttendanceEvent::UPDATE);
+        Session::flash('message', $langAddPresenceSuccess);
+        Session::flash('alert-class', 'alert-success');
+    } else {
+        Session::flash('message', $langForbidden);
+        Session::flash('alert-class', 'alert-warning');
+    }
+    // If the attendance tool is inactive, redirect the user to the portfolio.
+    if (isset($toolContent_ErrorExists)) {
+        redirect_to_home_page("main/portfolio.php");
+    } else {
+        redirect_to_home_page("modules/attendance/index.php?course=$course_code");
+    }
+}
+
 
 if ($is_editor) {
+
+    if (isset($_GET['download_qrcode'])) {
+        $actID = intval($_GET['download_qrcode']);
+        $fileNameAct = $actID . '_QRcode.svg';
+        $dload_filename = "$webDir/courses/$course_code/attendance_qrcode/$actID/$fileNameAct";
+        $filePath = $dload_filename;
+        // Check if the file exists
+        if (file_exists($filePath)) {
+            // Set the appropriate headers to trigger a download
+            header('Content-Description: File Transfer');
+            header('Content-Type: image/svg+xml');
+            header('Content-Disposition: attachment; filename="' . basename($filePath) . '"');
+            header('Expires: 0');
+            header('Cache-Control: must-revalidate');
+            header('Pragma: public');
+            header('Content-Length: ' . filesize($filePath));
+
+            // Clear output buffer
+            ob_clean();
+            flush();
+
+            // Read the file and send it to the output buffer
+            readfile($filePath);
+            exit;
+        } else {
+            // Handle the error if the file does not exist
+            echo "File not found.";
+        }
+    }
+
+    // Presence via QR code
+    if (isset($_GET['gen_qrcodePr'])) {
+        $actId = intval(getDirectReference($_GET['actId']));
+        $fileNameAct = $actId . '_QRcode.svg';
+
+        // Initialize URL and parameters
+        $string = $urlServer . "/modules/attendance/index.php?course=" . $course_code . "&attendance_id=" . $attendance_id . "&actId=" . $actId . "&qrCode_presence=true";
+
+        // Create QR Code
+        $renderer = new ImageRenderer(new RendererStyle(256), new SvgImageBackEnd());
+        $writer = new Writer($renderer);
+
+        // Generate the QR image
+        $qr_image = $writer->writeString($string);
+
+        // Base64 encode the SVG string
+        $qr_image_base64 = base64_encode($qr_image);
+
+        // Prepare the data URL for the SVG
+        $qr_image_data_url = "data:image/svg+xml;base64," . $qr_image_base64;
+
+        // Specify the path where you want to save the image
+        $qrCode_dir = "$webDir/courses/$course_code/attendance_qrcode/$actId";
+        if (!file_exists($qrCode_dir)) {
+            mkdir("$webDir/courses/$course_code/attendance_qrcode/$actId", 0755, true);
+        }
+        if (file_exists($qrCode_dir . '/' . $fileNameAct)) {
+            unlink($qrCode_dir . '/' . $fileNameAct);
+        }
+        file_put_contents($qrCode_dir . '/' . $fileNameAct, $qr_image);
+
+        $downloadURL = $_SERVER['SCRIPT_NAME'] . "?course=$course_code&download_qrcode=$actId";
+
+        // Prepare JavaScript content for modal
+        $head_content .= "
+            <script type='text/javascript'>
+                $(document).ready(function() {
+                    var downloadURL = '$downloadURL';
+                    var bts = {
+                        download: {
+                            label: '" . js_escape($langDownload) . "',
+                            className: 'submitAdminBtn gap-1',
+                            callback: function (d) {
+                                var anchor = document.createElement('a');
+                                anchor.href = downloadURL;
+                                anchor.target = '_blank';
+                                anchor.download = '$fileNameAct';
+                                anchor.click();
+                            }
+                        }
+                    };
+    
+                    if (screenfull.enabled) {
+                        bts.fullscreen = {
+                            label: '" . js_escape($langFullScreen) . "',
+                            className: 'submitAdminBtn gap-1',
+                            callback: function() {
+                                screenfull.request(document.getElementById('fileFrame'));
+                                return false;
+                            }
+                        };
+                    }
+                    bts.cancel = {
+                        label: '" . js_escape($langCancel) . "',
+                        className: 'cancelAdminBtn'
+                    };
+    
+                    bootbox.dialog({
+                        size: 'large',
+                        title: '" . js_escape($langGenQrCode) . "',
+                        onEscape: function() {},
+                        backdrop: true,
+                        message: '<div class=\"row\">' +
+                                    '<div class=\"col-sm-12\">' +
+                                        '<div class=\"iframe-container\" style=\"height:300px;\">' +
+                                            '<iframe title=\"{$langGenQrCode}\" id=\"fileFrame\" src=\"{$qr_image_data_url}\" style=\"width:260px; height:260px; margin:auto; display:block;\"></iframe>' +
+                                        '</div>' +
+                                    '</div>' +
+                                 '</div>',
+                        buttons: bts
+                    });
+                });
+            </script>
+        ";
+    }
+
     // change attendance visibility
     if (isset($_GET['vis'])) {
         Database::get()->query("UPDATE attendance SET active = ?d WHERE id = ?d AND course_id = ?d", $_GET['vis'], $_GET['attendance_id'], $course_id);
@@ -193,11 +352,12 @@ if ($is_editor) {
         redirect_to_home_page("modules/attendance/index.php?course=$course_code");
     }
 
-    //add a new attendance
-    if (isset($_POST['newAttendance'])) {
+    // Create new attendance book
+    if (isset($_POST['attendanceBookCreate'])) {
         $v = new Valitron\Validator($_POST);
-        $v->rule('required', array('title', 'limit', 'start_date', 'end_date'));
-        $v->rule('numeric', array('limit'));
+        $v->rule('required', array('title', 'start_date', 'end_date'));
+        $v->rule('integer', array('limit'));
+        $v->rule('min', array('limit'), 0);
         $v->rule('date', array('start_date', 'end_date'));
         if (!empty($_POST['end_date'])) {
             $v->rule('dateBefore', 'start_date', $_POST['end_date']);
@@ -210,9 +370,9 @@ if ($is_editor) {
         ));
         if($v->validate()) {
             $newTitle = $_POST['title'];
-            $attendance_limit = intval($_POST['limit']);
-            $start_date = DateTime::createFromFormat('d-m-Y H:i', $_POST['start_date'])->format('Y-m-d H:i:s');
-            $end_date = DateTime::createFromFormat('d-m-Y H:i', $_POST['end_date'])->format('Y-m-d H:i:s');
+            $attendance_limit = empty($_POST['limit']) ? 0 : intval($_POST['limit']);
+            $start_date = (new DateTime($_POST['start_date']))->format('Y-m-d H:i:s');
+            $end_date = (new DateTime($_POST['end_date']))->format('Y-m-d H:i:s');
             $attendance_id = Database::get()->query("INSERT INTO attendance SET course_id = ?d, `limit` = ?d, active = 1, title = ?s, start_date = ?t, end_date = ?t", $course_id, $attendance_limit, $newTitle, $start_date, $end_date)->lastInsertID;
             $log_details = array('id' => $attendance_id, 'title' => $newTitle, 'attendance_limit' => $attendance_limit, 'start_date' => $start_date, 'end_date' => $end_date);
             Log::record($course_id, MODULE_ID_ATTENDANCE, LOG_INSERT, $log_details);
@@ -438,11 +598,12 @@ if ($is_editor) {
     }
     $tool_content .= "</div>";
 
-    // update attendance settings
-    if (isset($_POST['submitAttendanceBookSettings'])) {
+    // Update attendance book settings
+    if (isset($_POST['attendanceBookSettings'])) {
         $v = new Valitron\Validator($_POST);
-        $v->rule('required', array('title', 'limit', 'start_date', 'end_date'));
-        $v->rule('numeric', array('limit'));
+        $v->rule('required', array('title', 'start_date', 'end_date'));
+        $v->rule('integer', array('limit'));
+        $v->rule('min', array('limit'), 0);
         $v->rule('date', array('start_date', 'end_date'));
         if (!empty($_POST['end_date'])) {
             $v->rule('dateBefore', 'start_date', $_POST['end_date']);
@@ -456,8 +617,8 @@ if ($is_editor) {
         if($v->validate()) {
             $attendance_limit = $_POST['limit'];
             $attendance_title = $_POST['title'];
-            $start_date = DateTime::createFromFormat('d-m-Y H:i', $_POST['start_date'])->format('Y-m-d H:i:s');
-            $end_date = DateTime::createFromFormat('d-m-Y H:i', $_POST['end_date'])->format('Y-m-d H:i:s');
+            $start_date = (new DateTime($_POST['start_date']))->format('Y-m-d H:i:s');
+            $end_date = (new DateTime($_POST['end_date']))->format('Y-m-d H:i:s');
             Database::get()->querySingle("UPDATE attendance SET `title` = ?s, `limit` = ?d, `start_date` = ?t, `end_date` = ?t WHERE id = ?d ", $attendance_title, $attendance_limit, $start_date, $end_date, $attendance_id);
             $log_details = array('id' => $attendance_id, 'title' => $attendance_title, 'attendance_limit' => $attendance_limit, 'start_date' => $start_date, 'end_date' => $end_date);
             Log::record($course_id, MODULE_ID_ATTENDANCE, LOG_MODIFY, $log_details);
@@ -498,8 +659,7 @@ if ($is_editor) {
             $actTitle = isset($_POST['actTitle']) ? trim($_POST['actTitle']) : "";
             $actDesc = purify($_POST['actDesc']);
             $auto = isset($_POST['auto']) ? $_POST['auto'] : "";
-            $actDate = empty($_POST['date']) ? null :
-                DateTime::createFromFormat('d-m-Y H:i', $_POST['date'])->format('Y-m-d H:i');
+            $actDate = empty($_POST['date']) ? null : (new DateTime($_POST['date']))->format('Y-m-d H:i');
             $visible = isset($_POST['visible']) ? 1 : 0;
             if ($_POST['id']) {
                 //update
@@ -582,15 +742,15 @@ if ($is_editor) {
         $display = FALSE;
     }
 
- elseif (isset($_GET['new'])) {
-        new_attendance(); // create new attendance
+    elseif (isset($_GET['new'])) {
+        attendance_book_form(); // create new attendance
+        $display = FALSE;
+    } elseif (isset($_GET['editSettings'])) { // attendance settings
+        attendance_book_form($attendance_id);
         $display = FALSE;
     } elseif (isset($_GET['editUsers'])) { // edit attendance users
         user_attendance_settings($attendance_id);
         $display = FALSE;
-    } elseif (isset($_GET['editSettings'])) { // attendance settings
-        attendance_settings($attendance_id);
-        $display = FALSE;
     } elseif (isset($_GET['addActivityAs'])) { //display available assignments
         attendance_display_available_assignments($attendance_id);
         $display = FALSE;
