@@ -49,6 +49,13 @@ require_once 'modules/session/functions.php';
 doc_init();
 $tree = new Hierarchy();
 $course = new Course();
+
+$up = new Permissions();
+$course_users_permission = $up->has_course_users_permission();
+$allow_clone = $up->has_course_clone_permission();
+$allow_course_backup = $up->has_course_backup_permission();
+$allow_course_tools = $up->has_course_modules_permission();
+
 $pageName = ''; // delete $pageName set in doc_init.php
 
 $main_content = $cunits_content = $course_info_extra = $data['countUnits'] = "";
@@ -88,8 +95,6 @@ if (isset($_POST['submitPoll'])) {
 
 }
 
-
-
 $data['course_info'] = $course_info = Database::get()->querySingle("SELECT title, keywords, visible, prof_names, public_code, course_license,
                                                view_type, start_date, end_date, description, home_layout, course_image, flipped_flag, password
                                           FROM course WHERE id = ?d", $course_id);
@@ -106,16 +111,19 @@ if ($is_editor and isset($_SERVER['HTTP_X_REQUESTED_WITH']) and strtolower($_SER
 // other actions in course unit
 if ($is_editor) {
     // update index and refresh course metadata
-    require_once 'modules/search/indexer.class.php';
+    require_once 'modules/search/classes/ConstantsUtil.php';
+    require_once 'modules/search/classes/SearchEngineFactory.php';
+    $searchEngine = SearchEngineFactory::create();
 
     if (isset($_REQUEST['del'])) { // delete course unit
         $id = intval(getDirectReference($_REQUEST['del']));
         if ($course_info->view_type == 'units') {
             Database::get()->query('DELETE FROM course_units WHERE id = ?d', $id);
             Database::get()->query('DELETE FROM unit_resources WHERE unit_id = ?d', $id);
-            Indexer::queueAsync(Indexer::REQUEST_REMOVE, Indexer::RESOURCE_UNIT, $id);
-            Indexer::queueAsync(Indexer::REQUEST_REMOVEBYUNIT, Indexer::RESOURCE_UNITRESOURCE, $id);
-            Indexer::queueAsync(Indexer::REQUEST_STORE, Indexer::RESOURCE_COURSE, $course_id);
+            Database::get()->query("DELETE FROM course_units_to_specific WHERE unit_id = ?d", $id);
+            $searchEngine->indexResource(ConstantsUtil::REQUEST_REMOVE, ConstantsUtil::RESOURCE_UNIT, $id);
+            $searchEngine->indexResource(ConstantsUtil::REQUEST_REMOVEBYUNIT, ConstantsUtil::RESOURCE_UNITRESOURCE, $id);
+            $searchEngine->indexResource(ConstantsUtil::REQUEST_STORE, ConstantsUtil::RESOURCE_COURSE, $course_id);
             CourseXMLElement::refreshCourse($course_id, $course_code);
             Session::flash('message',$langCourseUnitDeleted);
             Session::flash('alert-class', 'alert-success');
@@ -126,8 +134,8 @@ if ($is_editor) {
         $vis = Database::get()->querySingle("SELECT `visible` FROM course_units WHERE id = ?d", $id)->visible;
         $newvis = ($vis == 1) ? 0 : 1;
         Database::get()->query("UPDATE course_units SET visible = ?d WHERE id = ?d AND course_id = ?d", $newvis, $id, $course_id);
-        Indexer::queueAsync(Indexer::REQUEST_STORE, Indexer::RESOURCE_UNIT, $id);
-        Indexer::queueAsync(Indexer::REQUEST_STORE, Indexer::RESOURCE_COURSE, $course_id);
+        $searchEngine->indexResource(ConstantsUtil::REQUEST_STORE, ConstantsUtil::RESOURCE_UNIT, $id);
+        $searchEngine->indexResource(ConstantsUtil::REQUEST_STORE, ConstantsUtil::RESOURCE_COURSE, $course_id);
         CourseXMLElement::refreshCourse($course_id, $course_code);
         redirect_to_home_page("courses/$course_code/");
     } elseif (isset($_REQUEST['access'])) {
@@ -351,13 +359,13 @@ $data['action_bar'] = action_bar([
         'url' => "{$urlAppend}modules/user/index.php?course=$course_code",
         'icon' => 'fa-users',
         'level' => 'primary',
-        'show' => ($uid && $is_course_admin)
+        'show' => ($uid && ($is_course_admin || $course_users_permission))
     ],
     [
         'title' => "$numUsers $langRegistered",
         'url' => "{$urlAppend}modules/user/userslist.php?course=$course_code",
         'icon' => 'fa-users',
-        'show' => ($uid && !$is_course_admin && (setting_get(SETTING_USERS_LIST_ACCESS, $course_id) == 1))
+        'show' => ($uid && !$is_course_admin && !$course_users_permission && (setting_get(SETTING_USERS_LIST_ACCESS, $course_id) == 1))
     ],
     [
         'title' => $langUserEmailNotification,
@@ -391,6 +399,24 @@ $data['action_bar'] = action_bar([
         'icon' => 'fa-download',
         'show' => $offline_course
     ],
+    [
+        'title' => $langCourseTools,
+        'url' => "{$urlAppend}modules/course_tools/index.php?course=$course_code",
+        'icon' => 'fa-screwdriver-wrench',
+        'show' => ($uid && !$is_course_admin && $allow_course_tools)
+    ],
+    [
+        'title' => $langBackupCourse,
+        'url' => "{$urlAppend}modules/course_info/archive_course.php?course=$course_code&" . generate_csrf_token_link_parameter(),
+        'icon' => 'fa-archive',
+        'show' => ($uid && !$is_course_admin && $allow_course_backup)
+    ],
+    [
+        'title' => $langCloneCourse,
+        'url' => "{$urlAppend}modules/course_info/clone_course.php?course=$course_code",
+        'icon' => 'fa-archive',
+        'show' => ($uid && !$is_course_admin && $allow_clone)
+    ],
     [
         'title' => $langCitation,
         'url' => "javascript:void(0);",
@@ -409,7 +435,7 @@ if ($uid) {
     $data['course_completion_id'] = $course_completion_id = is_course_completion_active(); // is course completion active?
     if ($course_completion_id) {
         if ($is_editor) {
-            $data['studentUsers'] = Database::get()->querySingle("SELECT COUNT(*) AS studentUsers FROM course_user
+            $data['studentUsers'] = $student_users = Database::get()->querySingle("SELECT COUNT(*) AS studentUsers FROM course_user
                                         WHERE status = " .USER_STUDENT . "
                                             AND editor = 0
                                             AND course_id = ?d", $course_id)->studentUsers;
@@ -420,9 +446,13 @@ if ($uid) {
                                                                     AND course_id = ?d
                                                                     AND completed = 1
                                                                     AND badge = ?d", $course_id, $course_completion_id)->t;
-
-            $data['percentage_t'] = $percentage_t = round($data['certified_users'] / $data['studentUsers'] * 100, 0);
-            $data['angle'] = $percentage_t * 100 / 360;
+            if ($student_users == 0) {
+                $data['percentage_t'] = $percentage_t = 0;
+                $data['angle'] = 0;
+            } else {
+                $data['percentage_t'] = $percentage_t = round($data['certified_users'] / $data['studentUsers'] * 100, 0);
+                $data['angle'] = $percentage_t * 100 / 360;
+            }
         } else {
             $course_completion_status = has_certificate_completed($uid, 'badge', $course_completion_id);
             $data['percentage'] = $percentage = get_cert_percentage_completion('badge', $course_completion_id);
@@ -462,25 +492,26 @@ if ($is_editor) {
     warnCourseInvalidDepartment(true);
 }
 
-if ($is_editor) {
+if ($is_editor or $is_course_reviewer) {
     $data['last_id'] = $last_id = Database::get()->querySingle("SELECT id FROM course_units
                                                    WHERE course_id = ?d AND `order` >= 0
                                                    ORDER BY `order` DESC LIMIT 1", $course_id);
     if ($last_id) {
         $last_id = $last_id->id;
     }
-    $query = "SELECT id, title, start_week, finish_week, comments, visible, public, `order` FROM course_units WHERE course_id = ?d AND `order` >= 0 ORDER BY `order`";
+    $query = "SELECT id, title, start_week, finish_week, comments, visible, public, `order`, assign_to_specific FROM course_units WHERE course_id = ?d AND `order` >= 0 ORDER BY `order`";
 } else {
-    $query = "SELECT id, title, start_week, finish_week, comments, visible, public, `order` FROM course_units WHERE course_id = ?d AND visible = 1 AND `order` >= 0 ORDER BY `order`";
+    $query = "SELECT id, title, start_week, finish_week, comments, visible, public, `order`, assign_to_specific FROM course_units WHERE course_id = ?d AND visible = 1 AND `order` >= 0 ORDER BY `order`";
 }
 
 $data['all_units'] = $all_units = Database::get()->queryArray($query, $course_id);
+
 foreach ($all_units as $unit) {
     check_unit_progress($unit->id);  // check unit completion - call to Game.php
 }
 
 $visible_units_id = [];
-if (!$is_editor) {
+if (!$is_editor && !$is_course_reviewer) {
     $visible_user_units = findUserVisibleUnits($uid, $all_units);
     foreach ($visible_user_units as $d) {
         $visible_units_id[] = $d->id;
@@ -640,7 +671,7 @@ if ($total_cunits > 0) {
     $data['countUnits'] = $countUnits;
 
     if($carousel_or_row == 0){
-        $cunits_content .= "<div id='carouselUnitsControls' class='carousel slide' data-bs-ride='carousel'>";
+        $cunits_content .= "<div class='card panelCard card-default px-lg-2 py-lg-2 h-100'><div class='card-body'><div id='carouselUnitsControls' class='carousel slide' data-bs-ride='carousel'>";
 
         //this is foreach for indicators carousel-units
         $counterIndicator = 0;
@@ -660,17 +691,16 @@ if ($total_cunits > 0) {
         foreach ($all_units as $cu) {
             $not_shown = false;
             $icon = '';
-                // check if unit has started
-            if (!$is_editor) {
-                if (!(is_null($cu->start_week)) and (date('Y-m-d') < $cu->start_week)) {
+            if (!$is_editor && !$is_course_reviewer) {
+                if (!has_access_to_units($cu->id, $cu->assign_to_specific, $uid)) { // unit has assigned to users or groups?
+                    $not_shown = true;
+                } else if (!(is_null($cu->start_week)) and (date('Y-m-d') < $cu->start_week)) { // unit has started?
                     $not_shown = true;
                     $icon = icon('fa-clock fa-md', $langUnitNotStarted);
-                // or has completed units (if any)
-                } else if (!in_array($cu->id, $visible_units_id)) {
+                } else if (!in_array($cu->id, $visible_units_id)) { //  has completed units (if any)?
                     $not_shown = true;
                     $icon = icon('fa-minus-circle fa-md', $langUnitNotCompleted);
                 } else {
-
                     if (in_array($cu->id, $visible_units_id)) {
                         $sql_badge = Database::get()->querySingle("SELECT id FROM badge WHERE course_id = ?d AND unit_id = ?d", $course_id, $cu->id);
                         if ($sql_badge) {
@@ -703,7 +733,7 @@ if ($total_cunits > 0) {
             $cunits_content .= "<div id='unit_$cu_indirect' class='col-12' data-id='$cu->id'><div class='panel clearfix'><div class='col-12'>
                 <div class='item-content mb-2'>
                     <div class='item-header clearfix'>
-                        <div class='item-title d-flex justify-content-between $class_vis'>";
+                        <div class='item-title d-flex justify-content-between $class_vis gap-3'>";
 
             $cunits_content .= "<div class='item-title-container d-flex flex-column justify-content-center'>";
             if ($not_shown) {
@@ -778,24 +808,24 @@ if ($total_cunits > 0) {
         $cunits_content .= "</div>";
 
         //end courseUnitsControls
-        $cunits_content .= "</div>";
+        $cunits_content .= "</div></div></div>";
     } else {
         $counter_hr = 0;
         foreach ($all_units as $cu) {
             $counter_hr++;
             $not_shown = false;
             $icon = '';
-                // check if unit has started
-            if (!$is_editor) {
-                if (!(is_null($cu->start_week)) and (date('Y-m-d') < $cu->start_week)) {
+
+            if (!$is_editor && !$is_course_reviewer) {
+                if (!has_access_to_units($cu->id, $cu->assign_to_specific, $uid)) { // unit has assigned to users or groups ?
+                    $not_shown = true;
+                } else if (!(is_null($cu->start_week)) and (date('Y-m-d') < $cu->start_week)) { // unit has started ?
                     $not_shown = true;
                     $icon = icon('fa-clock fa-md', $langUnitNotStarted);
-                // or has completed units (if any)
-                } else if (!in_array($cu->id, $visible_units_id)) {
+                } else if (!in_array($cu->id, $visible_units_id)) { //  has completed units (if any) ?
                     $not_shown = true;
                     $icon = icon('fa-minus-circle fa-md', $langUnitNotCompleted);
                 } else {
-
                     if (in_array($cu->id, $visible_units_id)) {
                         $sql_badge = Database::get()->querySingle("SELECT id FROM badge WHERE course_id = ?d AND unit_id = ?d", $course_id, $cu->id);
                         if ($sql_badge) {
@@ -827,7 +857,7 @@ if ($total_cunits > 0) {
                 <div class='card panelCard card-default px-lg-2 py-lg-2 h-100'><div class='card-body'>
                     <div class='item-content'>
                         <div class='item-header clearfix'>
-                            <div class='item-title d-flex justify-content-between $class_vis'>";
+                            <div class='item-title d-flex justify-content-between $class_vis gap-3'>";
 
             $cunits_content .= "<div class='item-title-container d-flex flex-column justify-content-center'>";
             if ($not_shown) {
@@ -995,8 +1025,47 @@ if($course_info->view_type == 'sessions' && isset($_SESSION['uid'])){
                                                             $sql_session
                                                             ORDER BY start ASC",$course_id,1);
 }
+
+// Hide agenda, announcements, course completion and widgets on course home
+$right_col_display = false;
+$hidden_sql = setting_get(SETTING_AGENDA_ANNOUNCEMENT_COURSE_COMPLETION, $course_id);
+if ($hidden_sql) {
+    $right_col_display = true;
+}
+$data['right_col_display'] = $right_col_display;
+
 view('modules.course.home.index', $data);
 
+/**
+ * @brief check if user has access to unit if it is assigned to specific users or groups
+ * @param $unit_id
+ * @return bool
+ */
+function has_access_to_units($unit_id, $assign_to_specific, $user_id)
+{
+    switch ($assign_to_specific) {
+        case 0:
+            return true;
+        case 1:
+            $q = Database::get()->querySingle("SELECT user_id FROM course_units_to_specific WHERE unit_id = ?d AND user_id = ?d", $unit_id, $user_id);
+            if ($q) {
+                return true;
+            } else {
+                return false;
+            }
+        case 2:
+            $unit_to_group_ids = Database::get()->queryArray("SELECT group_id FROM course_units_to_specific WHERE unit_id = ?d", $unit_id);
+            foreach ($unit_to_group_ids as $g) {
+                $q = Database::get()->querySingle("SELECT * FROM group_members WHERE group_id = ?d AND user_id = ?d", $g->group_id, $user_id);
+                if ($q) {
+                    return true;
+                }
+            }
+            return false;
+    }
+}
+
+
 /**
  * @brief fetch course announcements
  * @return string
