@@ -22,7 +22,8 @@
  * @file exercise_admin.inc.php
  * @brief Create new exercise or modify an existing one
  */
-require_once 'modules/search/indexer.class.php';
+require_once 'modules/search/classes/ConstantsUtil.php';
+require_once 'modules/search/classes/SearchEngineFactory.php';
 require_once 'modules/tags/moduleElement.class.php';
 
 if (!empty($_SERVER['HTTP_X_REQUESTED_WITH']) && strtolower($_SERVER['HTTP_X_REQUESTED_WITH']) == 'xmlhttprequest') {
@@ -43,7 +44,7 @@ if (!empty($_SERVER['HTTP_X_REQUESTED_WITH']) && strtolower($_SERVER['HTTP_X_REQ
 load_js('tools.js');
 // the exercise form has been submitted
 if (isset($_POST['submitExercise'])) {
-
+    if (!isset($_POST['token']) || !validate_csrf_token($_POST['token'])) csrf_token_error();
     $v = new Valitron\Validator($_POST);
     $v->addRule('ipORcidr', function($field, $value, array $params) {
         //matches IPv4/6 and IPv4/6 CIDR ranges
@@ -79,6 +80,10 @@ if (isset($_POST['submitExercise'])) {
         } else {
             $objExercise->updateIPLock('');
         }
+
+        if (!is_null($_POST['exerciseGradePass']) and floatval($_POST['exerciseGradePass']) > 0) {
+            $objExercise->setPassingGrade($_POST['exerciseGradePass']);
+        }
         $objExercise->updatePasswordLock($_POST['exercisePasswordLock']);
         $startDateTime_obj = !empty($_POST['exerciseStartDate']) ?
             DateTime::createFromFormat('d-m-Y H:i', $_POST['exerciseStartDate'])->format('Y-m-d H:i:s') : NULL;
@@ -107,13 +112,24 @@ if (isset($_POST['submitExercise'])) {
         } else {
             $objExercise->setisExam(1);
         }
+        if (!isset($_POST['shuffle_answers'])) {
+            $objExercise->setOption('ShuffleAnswers', false);
+        } else {
+            $objExercise->setOption('ShuffleAnswers', true);
+        }
+        if (!isset($_POST['stricterExamRestriction'])) {
+            $objExercise->setOption('stricterExamRestriction', false);
+        } else {
+            $objExercise->setOption('stricterExamRestriction', true);
+        }
 
         $objExercise->save();
         // reads the exercise ID (only useful for a new exercise)
         $exerciseId = $objExercise->selectId();
 
         $objExercise->assignTo(filter_input(INPUT_POST, 'ingroup', FILTER_VALIDATE_INT, FILTER_REQUIRE_ARRAY));
-        Indexer::queueAsync(Indexer::REQUEST_STORE, Indexer::RESOURCE_EXERCISE, $exerciseId);
+        $searchEngine = SearchEngineFactory::create();
+        $searchEngine->indexResource(ConstantsUtil::REQUEST_STORE, ConstantsUtil::RESOURCE_EXERCISE, $exerciseId);
 
         // tags
         $moduleTag = new ModuleElement($exerciseId);
@@ -159,6 +175,8 @@ if (isset($_POST['submitExercise'])) {
     $displayScore = Session::has('dispscore') ? Session::get('dispscore') : $objExercise->selectScore();
     $continueTimeLimit = Session::has('continueTimeLimit') ? Session::get('continueTimeLimit') : $objExercise->continueTimeLimit();
     $isExam = Session::has('isExam') ? Session::get('isExam') : $objExercise->isExam();
+    $exerciseGradePass = $objExercise->getPassingGrade();
+    $hasShuffleAnswers = Session::has('shuffle_answers') ? Session::get('shuffle_answers') : $objExercise->getOption(('ShuffleAnswers'));
     $continueTimeField = str_replace('[]',
         "<input type='text' class='form-control' name='continueTimeLimit' value='$continueTimeLimit' aria-label='$langminutes'>",
         $langContinueAttemptTime);
@@ -172,6 +190,7 @@ if (isset($_POST['submitExercise'])) {
         $exerciseIPLockOptions = '';
     }
     $exercisePreventCopy = Session::has('jsPreventCopy') ? Session::get('jsPreventCopy') : $objExercise->getOption('jsPreventCopy');
+    $exerciseStricterExamRestriction = Session::has('stricterExamRestriction') ? Session::get('stricterExamRestriction') : $objExercise->getOption('stricterExamRestriction');
     $exercisePasswordLock = Session::has('exercisePasswordLock') ? Session::get('exercisePasswordLock') : $objExercise->selectPasswordLock();
     $exerciseAssignToSpecific = Session::has('assign_to_specific') ? Session::get('assign_to_specific') : $objExercise->selectAssignToSpecific();
     if ($objExercise->selectAssignToSpecific()) {
@@ -181,7 +200,7 @@ if (isset($_POST['submitExercise'])) {
         if ($objExercise->selectAssignToSpecific() == 2) {
             $assignees = Database::get()->queryArray("SELECT `group`.id AS id, `group`.name
                 FROM exercise_to_specific, `group`
-                WHERE `group`.id = exercise_to_specific.group_id                    
+                WHERE `group`.id = exercise_to_specific.group_id
                     AND exercise_to_specific.exercise_id = ?d", $exerciseId);
             $all_groups = Database::get()->queryArray("SELECT name, id FROM `group` WHERE course_id = ?d AND visible = 1", $course_id);
             foreach ($assignees as $assignee_row) {
@@ -227,6 +246,16 @@ if (isset($_GET['modifyExercise']) or isset($_GET['NewExercise'])) {
 
     $head_content .= "<script type='text/javascript'>
         $(function() {
+            $('#exerciseRangeId').change(function() {
+               var selectedValue = $(this).val();               
+               if (selectedValue !== \"\") {
+                    $('#legend_grade_pass').text('" . js_escape($langExerciseGradePass) . "');
+               } else {
+                    $('#legend_grade_pass').text('" . js_escape($langSuccessPercentage) . "');
+               }
+            });
+
+
             $('#exerciseStartDate, #exerciseEndDate').datetimepicker({
                 format: 'dd-mm-yyyy hh:ii',
                 pickerPosition: 'bottom-right',
@@ -287,6 +316,19 @@ if (isset($_GET['modifyExercise']) or isset($_GET['NewExercise'])) {
                     $('#continueTimeField').hide('fast');
                 }
             }).change();
+
+            if ($('#isExam_').is(':checked')) {
+                $('#stricter_exam').removeClass('d-none').addClass('d-block');
+            } else {
+                $('#stricter_exam').removeClass('d-block').addClass('d-none');
+            }
+            $('#isExam_').on('click', function() {
+                if ($(this).is(':checked')) {
+                    $('#stricter_exam').removeClass('d-none').addClass('d-block');
+                } else {
+                    $('#stricter_exam').removeClass('d-block').addClass('d-none');
+                }
+            });
         });
         function ajaxAssignees()
         {
@@ -302,11 +344,11 @@ if (isset($_GET['modifyExercise']) or isset($_GET['NewExercise'])) {
                 var select_content = '';
                 if(type==1){
                     for (index = 0; index < parsed_data.length; ++index) {
-                        select_content += '<option value=\"' + parsed_data[index]['id'] + '\">' + parsed_data[index]['surname'] + ' ' + parsed_data[index]['givenname'] + '<\/option>';
+                        select_content += '<option value=\"' + parsed_data[index]['id'] + '\">' + q(parsed_data[index]['surname'] + ' ' + parsed_data[index]['givenname']) + '<\/option>';
                     }
                 } else {
                     for (index = 0; index < parsed_data.length; ++index) {
-                        select_content += '<option value=\"' + parsed_data[index]['id'] + '\">' + parsed_data[index]['name'] + '<\/option>';
+                        select_content += '<option value=\"' + parsed_data[index]['id'] + '\">' + q(parsed_data[index]['name']) + '<\/option>';
                     }
                 }
                 $('#assignee_box').find('option').remove();
@@ -341,15 +383,18 @@ if (isset($_GET['modifyExercise']) or isset($_GET['NewExercise'])) {
                  </div>
 
                  <div class='row form-group mt-4'>
-                   <label for='exerciseFeedback' class='col-12 control-label-notes mb-1'>$langExerciseFeedback</label>
+                   <label for='exerciseFeedback' class='col-12 control-label-notes mb-1'>$langExerciseFeedback
+                        <span class='fa-solid fa-circle-info ps-1' data-bs-toggle='tooltip' data-bs-placement='top' title='$langExerciseFeedbackInfo' style='margin-bottom: 10px;'></span>
+                   </label>
                    <div class='col-12'>
                        " . rich_text_editor('exerciseFeedback', 4, 30, $exerciseFeedback) . "
-                       <span class='help-block col-sm-offset-2 col-sm-10'>$langExerciseFeedbackInfo</span>
-                       </div>
+                   </div>
                  </div>
-                 
+
                  <div class='row form-group mt-4'>
-                     <div class='col-12 control-label-notes mb-1'>$langViewShow</div>
+                     <div class='col-12 control-label-notes mb-1'>
+                        $langViewShow
+                     </div>
                      <div class='col-12'>
                          <div class='radio'>
                            <label>
@@ -371,6 +416,23 @@ if (isset($_GET['modifyExercise']) or isset($_GET['NewExercise'])) {
                          </div>
                      </div>
                  </div>
+
+                 <div class='row form-group mt-4'>
+                    <label for='exerciseRangeId' class='col-12 control-label-notes mb-1'>
+                        $langAnswers
+                        <span class='fa-solid fa-circle-info ps-1' data-bs-toggle='tooltip' data-bs-placement='top' title='$langShuffleAnswersLegend' style='margin-bottom: 10px;'></span>
+                    </label>
+                    <div class='col-12'>
+                        <div class='checkbox'>
+                            <label class='label-container' aria-label='$langSelect'>
+                                <input name='shuffle_answers' type='checkbox' " . ($hasShuffleAnswers? 'checked' : '') . ">
+                                <span class='checkmark'></span>
+                                    $langShuffleAnswers
+                            </label>
+                        </div>
+                    </div>
+                </div>
+
                  <div class='row form-group mt-4'>
                     <label for='exerciseRangeId' class='col-12 control-label-notes mb-1'>$langExerciseScaleGrade</label>
                     <div class='col-12'>
@@ -383,6 +445,21 @@ if (isset($_GET['modifyExercise']) or isset($_GET['NewExercise'])) {
                         </select>
                     </div>
                 </div>
+
+                <div class='row form-group mt-4'>
+                    <div class='col-12'>
+                        <div class='row'>
+                            <div class='col-md-3'>
+                                <label for='exerciseTimeConstraint' class='col-12 control-label-notes mb-1'>
+                                <strong id='legend_grade_pass'>" . ($exerciseRange == 0 ? " $langSuccessPercentage" : "$langExerciseGradePass") . "</strong>
+                                <span class='fa-solid fa-circle-info ps-1' data-bs-toggle='tooltip' data-bs-placement='top' title='$langExerciseGradePassLegend' style='margin-bottom: 10px;'></span>
+                                </label>
+                                <input type='text' class='form-control' name='exerciseGradePass' id='exerciseGradePass' value='$exerciseGradePass' size='4' maxlength='4'>
+                            </div>
+                        </div>
+                    </div>
+                </div>
+
                  <div class='row input-append date form-group".(Session::getError('exerciseStartDate') ? " has-error" : "")." mt-4' id='startdatepicker' data-date='$exerciseStartDate' data-date-format='dd-mm-yyyy'>
                      <label for='exerciseStartDate' class='col-12 control-label-notes mb-1'>$langStart</label>
                      <div class='col-12'>
@@ -393,12 +470,13 @@ if (isset($_GET['modifyExercise']) or isset($_GET['NewExercise'])) {
                                     <span class='checkmark'></span>
                                 </label>
                             </span>
-                            <span class='add-on1 input-group-text h-40px input-border-color border-end-0'><i class='fa-regular fa-calendar Neutral-600-cl'></i></span>  
+                            <span class='add-on1 input-group-text h-40px input-border-color border-end-0'><i class='fa-regular fa-calendar Neutral-600-cl'></i></span>
                             <input class='form-control mt-0 border-start-0' name='exerciseStartDate' id='exerciseStartDate' type='text' value='$exerciseStartDate'".($enableStartDate ? '' : ' disabled').">
                         </div>
                         <span class='help-block'>".(Session::hasError('exerciseStartDate') ? Session::getError('exerciseStartDate') : "&nbsp;&nbsp;&nbsp;<i class='fa fa-share fa-rotate-270'></i> $langExerciseStartHelpBlock")."</span>
                      </div>
                  </div>
+
                  <div class='row input-append date form-group".(Session::getError('exerciseEndDate') ? " has-error" : "")." mt-4' id='enddatepicker' data-date='$exerciseEndDate' data-date-format='dd-mm-yyyy'>
                      <label for='exerciseEndDate' class='col-12 control-label-notes mb-1'>$langFinish</label>
                      <div class='col-12'>
@@ -409,14 +487,17 @@ if (isset($_GET['modifyExercise']) or isset($_GET['NewExercise'])) {
                                      <span class='checkmark'></span>
                                 </label>
                             </span>
-                            <span class='add-on2 input-group-text h-40px input-border-color border-end-0'><i class='fa-regular fa-calendar Neutral-600-cl'></i></span>  
+                            <span class='add-on2 input-group-text h-40px input-border-color border-end-0'><i class='fa-regular fa-calendar Neutral-600-cl'></i></span>
                             <input class='form-control mt-0 border-start-0' name='exerciseEndDate' id='exerciseEndDate' type='text' value='$exerciseEndDate'".($enableEndDate ? '' : ' disabled').">
                         </div>
                         <span class='help-block'>".(Session::hasError('exerciseEndDate') ? Session::getError('exerciseEndDate') : "&nbsp;&nbsp;&nbsp;<i class='fa fa-share fa-rotate-270'></i> $langExerciseEndHelpBlock")."</span>
                      </div>
                  </div>
+
                  <div class='row form-group mt-4'>
-                     <div class='col-12 control-label-notes mb-1'>$langTemporarySave</div>
+                     <div class='col-12 control-label-notes mb-1'>
+                        $langTemporarySave
+                     </div>
                      <div class='col-12'>
                         <div class='row'>
                             <div class='col-md-6 col-12 radio'>
@@ -434,28 +515,30 @@ if (isset($_GET['modifyExercise']) or isset($_GET['NewExercise'])) {
                         </div>
                      </div>
                  </div>
-                
-                   
-                <div class='row form-group ".(Session::getError('exerciseTimeConstraint') ? "has-error" : "")." mt-4'>
-                    <label for='exerciseTimeConstraint' class='col-12 control-label-notes mb-1'>$langExerciseConstrain</label>
-                    <div class='col-12'>
-                        <input type='text' class='form-control' name='exerciseTimeConstraint' id='exerciseTimeConstraint' value='$exerciseTimeConstraint' placeholder='$langExerciseConstrain'>
-                        <span class='help-block'>".(Session::getError('exerciseTimeConstraint') ? Session::getError('exerciseTimeConstraint') : "$langExerciseConstrainUnit ($langExerciseConstrainExplanation)")."</span>
-                    </div>
-                </div>
-            
-            
-                <div class='row form-group ".(Session::getError('exerciseAttemptsAllowed') ? "has-error" : "")." mt-4'>
-                    <label for='exerciseAttemptsAllowed' class='col-12 control-label-notes mb-1'>$langExerciseAttemptsAllowed</label>
-                    <div class='col-12'>
-                        <input type='text' class='form-control' name='exerciseAttemptsAllowed' id='exerciseAttemptsAllowed' value='$exerciseAttemptsAllowed' placeholder='$langExerciseConstrain'>
-                        <span class='help-block'>".(Session::getError('exerciseAttemptsAllowed') ? Session::getError('exerciseAttemptsAllowed') : "$langExerciseAttemptsAllowedUnit ($langExerciseAttemptsAllowedExplanation)")."</span>
-                    </div>
-                </div>
-                   
-                ";
 
-                $tool_content .= "
+                <div class='row form-group ". ((Session::getError('exerciseTimeConstraint') or Session::getError('exerciseAttemptsAllowed'))? "has-error" : "") ." mt-4'>
+                    <div class='col-12'>
+                        <div class='row'>
+                            <div class='col-md-6'>
+                                <label for='exerciseTimeConstraint' class='col-12 control-label-notes mb-1'>
+                                    $langExerciseConstrain
+                                    <span class='fa-solid fa-circle-info ps-1' data-bs-toggle='tooltip' data-bs-placement='top' title='$langExerciseConstrainExplanation' style='margin-bottom: 10px;'></span>
+                                </label>
+                                <input type='text' class='form-control' name='exerciseTimeConstraint' id='exerciseTimeConstraint' value='$exerciseTimeConstraint' placeholder='$langExerciseConstrain'>
+                                <span class='help-block'>".(Session::getError('exerciseTimeConstraint') ? Session::getError('exerciseTimeConstraint') : "$langExerciseConstrainUnit ")."</span>
+                            </div>
+                            <div class='col-md-6'>
+                                <label for='exerciseAttemptsAllowed' class='col-12 control-label-notes mb-1'>
+                                    $langExerciseAttemptsAllowed
+                                    <span class='fa-solid fa-circle-info ps-1' data-bs-toggle='tooltip' data-bs-placement='top' title='$langExerciseAttemptsAllowedExplanation' style='margin-bottom: 10px;'></span>
+                                </label>
+                                <input type='text' class='form-control' name='exerciseAttemptsAllowed' id='exerciseAttemptsAllowed' value='$exerciseAttemptsAllowed' placeholder='$langExerciseConstrain'>
+                                <span class='help-block'>".(Session::getError('exerciseAttemptsAllowed') ? Session::getError('exerciseAttemptsAllowed') : "$langExerciseAttemptsAllowedUnit")."</span>
+                            </div>
+                        </div>
+                    </div>
+                </div>
+
                 <div class='row form-group mt-4'>
                      <div class='col-12 control-label-notes mb-1'>$langAnswers</div>
                      <div class='col-12'>
@@ -515,24 +598,24 @@ if (isset($_GET['modifyExercise']) or isset($_GET['NewExercise'])) {
                      </div>
                  </div>
                  <div class='row form-group mt-4'>
-                    <div class='control-label-notes mb-1'>$m[WorkAssignTo]</div>
+                    <div class='control-label-notes mb-1'>$langWorkAssignTo</div>
                     <div class='col-12'>
                         <div class='radio'>
                           <label>
                             <input type='radio' id='assign_button_all' name='assign_to_specific' value='0'".($exerciseAssignToSpecific == 0 ? " checked" : "").">
-                            $m[WorkToAllUsers]
+                            $langWorkToAllUsers
                           </label>
                         </div>
                         <div class='radio'>
                           <label>
                             <input type='radio' id='assign_button_user' name='assign_to_specific' value='1'".($exerciseAssignToSpecific == 1 ? " checked" : "").">
-                            $m[WorkToUser]
+                            $langWorkToUser
                           </label>
                         </div>
                         <div class='radio'>
                           <label>
                             <input type='radio' id='assign_button_group' name='assign_to_specific' value='2'".($exerciseAssignToSpecific == 2 ? " checked" : "").">
-                            $m[WorkToGroup]
+                            $langWorkToGroup
                           </label>
                         </div>
                     </div>
@@ -545,7 +628,7 @@ if (isset($_GET['modifyExercise']) or isset($_GET['NewExercise'])) {
                                     <tr class='title1 list-header'>
                                         <td class='form-label' id='assignees'>$langStudents</td>
                                         <td class='form-label text-center'>$langMove</td>
-                                        <td class='form-label'>$m[WorkAssignTo]</td>
+                                        <td class='form-label'>$langWorkAssignTo</td>
                                     </tr>
                                 </thead>
                                 <tr>
@@ -561,7 +644,7 @@ if (isset($_GET['modifyExercise']) or isset($_GET['NewExercise'])) {
                                     </div>
                                   </td>
                                   <td>
-                                    <select aria-label='$m[WorkAssignTo]' class='form-select h-100' id='assignee_box' name='ingroup[]' size='10' multiple>
+                                    <select aria-label='$langWorkAssignTo' class='form-select h-100' id='assignee_box' name='ingroup[]' size='10' multiple>
                                     ".((isset($assignee_options)) ? $assignee_options : '')."
                                     </select>
                                   </td>
@@ -576,7 +659,7 @@ if (isset($_GET['modifyExercise']) or isset($_GET['NewExercise'])) {
                         <div class='col-12'>
                             <div class='checkbox'>
                                 <label class='label-container' aria-label='$langSelect'>
-                                    <input name='isExam' type='checkbox' " . ($isExam? 'checked' : '') . ">
+                                    <input id='isExam_' name='isExam' type='checkbox' " . ($isExam? 'checked' : '') . ">
                                     <span class='checkmark'></span>
                                     $langExam
                                 </label>
@@ -584,7 +667,20 @@ if (isset($_GET['modifyExercise']) or isset($_GET['NewExercise'])) {
                             </div>
                     </div>
                 </div>
-
+                
+                <div class='row form-group mt-4 d-none' id='stricter_exam'>
+                    <div class='col-sm-12 control-label-notes mb-1'>$langStricterExamRestriction:</div>
+                    <div class='col-12'>
+                        <div class='checkbox'>
+                            <label class='label-container' aria-label='$langSelect'>
+                                <input name='stricterExamRestriction' type='checkbox' " . ($exerciseStricterExamRestriction? 'checked' : '') . ">
+                                <span class='checkmark'></span>
+                                $langExerciseWillBeCanceledInStrictMode
+                            </label>
+                        </div>
+                    </div>
+                </div>
+                
                 <div class='row form-group mt-4'>
                     <div class='col-12 control-label-notes mb-1'>$langContinueAttempt</div>
                     <div class='col-12'>
@@ -613,35 +709,36 @@ if (isset($_GET['modifyExercise']) or isset($_GET['NewExercise'])) {
                     </div>
                 </div>
 
-                <div class='course-info-title clearfix mt-4'>
-                    <a class='TextBold text-decoration-none'role='button' data-bs-toggle='collapse' href='#CheckAccess' aria-expanded='false' aria-controls='CheckAccess'>
-                        <div class='card panelCard card-default px-0 py-1 h-100'>
-                            <div class='card-header border-0 d-flex justify-content-between align-items-center'>
+                <div class='panel-group group-section mt-4' id='accordionEx' role='tablist' aria-multiselectable='true'>
+                    <ul class='list-group list-group-flush'>
+                        <li class='list-group-item px-0 mb-4 bg-transparent'>
+                            <a class='accordion-btn d-flex justify-content-start align-items-start' role='button' data-bs-toggle='collapse' href='#CheckAccess' aria-expanded='false' aria-controls='CheckAccess'>
+                                <span class='fa-solid fa-chevron-down'></span>
                                 $langCheckAccess
-                                <span class='fa fa-chevron-down fa-fw'></span> 
+                            </a>
+                            <div id='CheckAccess' class='panel-collapse accordion-collapse collapse border-0 rounded-0' role='tabpanel' data-bs-parent='#accordionEx'>
+                                <div class='panel-body bg-transparent Neutral-900-cl p-0'>
+                                    <div class='form-group ".(Session::getError('exercisePasswordLock') ? "has-error" : "")." mt-4'>
+                                        <label for='exercisePasswordLock' class='col-12 control-label-notes mb-1'>$langPassCode</label>
+                                        <div class='col-12'>
+                                            <input name='exercisePasswordLock' type='text' class='form-control' id='exercisePasswordLock' value='$exercisePasswordLock' placeholder=''>
+                                            <span class='help-block Accent-200-cl'>".Session::getError('exercisePasswordLock')."</span>
+                                        </div>
+                                    </div>
+                                    <div class='form-group ".(Session::getError('exerciseIPLock') ? "has-error" : "")." mt-4'>
+                                        <label for='exerciseIPLock' class='col-12 control-label-notes mb-1'>$langIPUnlock</label>
+                                        <div class='col-12'>
+                                            <select name='exerciseIPLock[]' class='form-select' id='exerciseIPLock' multiple>
+                                                $exerciseIPLockOptions
+                                            </select>
+                                            <span class='help-block Accent-200-cl'>".Session::getError('exerciseIPLock')."</span>
+                                        </div>
+                                    </div>" .
+                                    eClassTag::tagInput($exerciseId) . "
+                                </div>
                             </div>
-                        </div>
-                    </a>
-                </div>
-
-                <div id='CheckAccess' class='collapse'>
-                    <div class='row form-group ".(Session::getError('exercisePasswordLock') ? "has-error" : "")." mt-4'>
-                        <label for='exercisePasswordLock' class='col-12 control-label-notes mb-1'>$langPassCode <span class='asterisk Accent-200-cl'>(*)</span></label>
-                        <div class='col-12'>
-                            <input name='exercisePasswordLock' type='text' class='form-control' id='exercisePasswordLock' value='$exercisePasswordLock' placeholder=''>
-                            <span class='help-block Accent-200-cl'>".Session::getError('exercisePasswordLock')."</span>
-                        </div>
-                    </div>
-                    <div class='row form-group ".(Session::getError('exerciseIPLock') ? "has-error" : "")." mt-4'>
-                        <label for='exerciseIPLock' class='col-12 control-label-notes mb-1'>$langIPUnlock <span class='asterisk Accent-200-cl'>(*)</span></label>
-                        <div class='col-12'>
-                            <select name='exerciseIPLock[]' class='form-select' id='exerciseIPLock' multiple>
-                                $exerciseIPLockOptions
-                            </select>
-                            <span class='help-block Accent-200-cl'>".Session::getError('exerciseIPLock')."</span>
-                        </div>
-                    </div>" .
-                    eClassTag::tagInput($exerciseId) . "
+                        </li>
+                    </ul>
                 </div>
 
                 <div class='row form-group mt-5'>
@@ -663,6 +760,7 @@ if (isset($_GET['modifyExercise']) or isset($_GET['NewExercise'])) {
                     </div>
                  </div>
              </fieldset>
+             " . generate_csrf_token_form_field() . "
              </form>
         </div></div><div class='d-none d-lg-block'>
         <img class='form-image-modules' src='".get_form_image()."' alt='$langImgFormsDes'>
@@ -698,9 +796,9 @@ if (isset($_GET['modifyExercise']) or isset($_GET['NewExercise'])) {
             break;
     }
     switch ($exerciseAssignToSpecific) {
-        case 1: $assign_to_users_message = $m['WorkToUser'];
+        case 1: $assign_to_users_message = $langWorkToUser;
             break;
-        case 2: $assign_to_users_message = $m['WorkToGroup'];
+        case 2: $assign_to_users_message = $langWorkToGroup;
             break;
     }
     if ($exerciseType == MULTIPLE_PAGE_TYPE) {
@@ -792,7 +890,7 @@ if (isset($_GET['modifyExercise']) or isset($_GET['NewExercise'])) {
                     <div class='col-sm-12 '>$disp_score_message</div>";
 
     if ($exerciseAssignToSpecific > 0) {
-        $tool_content .= "<div class='col-sm-12 '>$m[WorkAssignTo]: <b>$assign_to_users_message</b></div>";
+        $tool_content .= "<div class='col-sm-12 '>$langWorkAssignTo: <b>$assign_to_users_message</b></div>";
     }
 
     $tags_list = $moduleTag->showTags();
