@@ -23,6 +23,9 @@ include 'exercise.class.php';
 include 'question.class.php';
 include 'answer.class.php';
 
+// Check if AI functionality is available
+require_once '../../include/lib/ai/services/AIQuestionBankService.php';
+
 $require_editor = TRUE;
 $require_current_course = TRUE;
 $require_help = true;
@@ -32,6 +35,9 @@ $helpSubTopic = 'question_bank';
 include '../../include/baseTheme.php';
 require_once 'imsqtilib.php';
 
+// Initialize AI service
+$aiService = new AIQuestionBankService($course_id, $uid);
+
 load_js('datatables');
 
 $picturePath = "courses/$course_code/image";
@@ -39,17 +45,23 @@ $picturePath = "courses/$course_code/image";
 $head_content .= "
     <script type='text/javascript'>
         $(function() {
-            $('#questions').DataTable ({
+            $('#questions_$course_code').DataTable ({
+                'stateSave': true,
                 'fnDrawCallback': function (settings) { typeof MathJax !== 'undefined' && MathJax.typeset(); },
                 'sPaginationType': 'full_numbers',
                 'bAutoWidth': true,
                 'searchDelay': 1000,
                 'order' : [[1, 'desc']],
+                'lengthMenu': [10, 20, 30, -1],
                 'oLanguage': {
+                   'lengthLabels': {
+                   	    '-1': '$langAllOfThem'
+                   },
                    'sLengthMenu':   '$langDisplay _MENU_ $langResults2',
                    'sZeroRecords':  '" . $langNoResult . "',
+                   'sEmptyTable':   '" . $langNoResult . "',
                    'sInfo':         '$langDisplayed _START_ $langTill _END_ $langFrom2 _TOTAL_ $langTotalResults',
-                   'sInfoEmpty':    '$langDisplayed 0 $langTill 0 $langFrom2 0 $langResults2',
+                   'sInfoEmpty':    '',
                    'sInfoFiltered': '',
                    'sInfoPostFix':  '',
                    'sSearch':       '',
@@ -63,11 +75,11 @@ $head_content .= "
                }
             });
 
-            $('.dataTables_filter input').attr({
+            $('.dt-search input').attr({
                 class : 'form-control input-sm mb-3 me-3',
                 placeholder : '$langSearch...'
             });
-            $('.dataTables_filter label').attr('aria-label', '$langSearch'); 
+            $('.dt-search label').attr('aria-label', '$langSearch'); 
 
             $(document).on('click', '.warnLink', function(e){
                 var modifyAllLink = $(this).attr('href');
@@ -166,7 +178,7 @@ if (isset($_GET['fromExercise'])) {
     $objExercise = new Exercise();
     $fromExercise = intval($_GET['fromExercise']);
     $objExercise->read($fromExercise);
-    $navigation[] = array("url" => "admin.php?course=$course_code&amp;exerciseId=$fromExercise", "name" => $langExerciseManagement);
+    $navigation[] = array("url" => "admin.php?course=$course_code&exerciseId=$fromExercise", "name" => $langExerciseManagement);
 } else {
     $fromExercise = '';
 }
@@ -181,6 +193,12 @@ if (isset($_GET['categoryId'])) {
     $categoryId = intval($_GET['categoryId']);
 }
 
+if (isset($_GET['answerType'])) {
+    $answerType = intval($_GET['answerType']);
+} else {
+    $answerType = -1;
+}
+
 // deletes a question from the data base and all exercises
 if (isset($_GET['delete'])) {
     $delete = intval($_GET['delete']);
@@ -223,6 +241,7 @@ elseif (isset($_GET['recup']) and $fromExercise) {
 $exportUrl = "export.php?course=$course_code" .
     (isset($exerciseId)? "&amp;exerciseId=$exerciseId": '') .
     (isset($difficultyId)? "&amp;difficultyId=$difficultyId": '') .
+    (isset($answerType)? "&amp;answerType=$answerType": '') .
     (isset($categoryId)? "&amp;categoryId=$categoryId": '');
 
 if ($fromExercise) {
@@ -269,6 +288,12 @@ if ($fromExercise) {
           'icon' => 'fa-upload',
           'button-class' => 'btn-success'
         ],
+        [ 'title' => $langAIGenerateQuestions,
+          'url' => "ai_question_generation.php?course=$course_code",
+          'icon' => 'fa-magic',
+          'button-class' => 'btn-info',
+          'show' => $aiService->isEnabledForCourse(AI_MODULE_QUESTION_POOL)
+        ]
     ];
 }
 
@@ -294,52 +319,73 @@ foreach ($q_cats as $q_cat) {
     $q_cat_options .= "<option value='" . $q_cat->question_cat_id . "' ".(isset($categoryId) && $categoryId == $q_cat->question_cat_id ? "selected":"").">$q_cat->question_cat_name</option>\n";
 }
 //Start of filtering Component
-$tool_content .= "<div class='form-wrapper mb-4'><form class='form-inline' role='form' name='qfilter' method='get' action='$_SERVER[REQUEST_URI]'><input type='hidden' name='course' value='$course_code'>
+$tool_content .= "<div class='form-wrapper mb-4'><form class='form-inline' role='form' name='qfilter' method='get' action='$_SERVER[REQUEST_URI]'>
+                    <input type='hidden' name='course' value='$course_code'>
                     ".($fromExercise? "<input type='hidden' name='fromExercise' value='$fromExercise'>" : "")."
                     <div class='form-group'>
                         <select onChange = 'document.qfilter.submit();' name='exerciseId' class='form-select'>
                             $exercise_options
                         </select>
-                </div>
-                <div class='form-group mt-3'>
-                    <select onChange = 'document.qfilter.submit();' name='difficultyId' class='form-select'>
-                        <option value='-1' ".(isset($difficultyId) && $difficultyId == -1 ? "selected='selected'": "").">-- $langQuestionAllDiffs --</option>
-                        <option value='0' ".(isset($difficultyId) && $difficultyId == 0 ? "selected='selected'": "").">-- $langQuestionNotDefined --</option>
-                        <option value='1' ".(isset($difficultyId) && $difficultyId == 1 ? "selected='selected'": "").">$langQuestionVeryEasy</option>
-                        <option value='2' ".(isset($difficultyId) && $difficultyId == 2 ? "selected='selected'": "").">$langQuestionEasy</option>
-                        <option value='3' ".(isset($difficultyId) && $difficultyId == 3 ? "selected='selected'": "").">$langQuestionModerate</option>
-                        <option value='4' ".(isset($difficultyId) && $difficultyId == 4 ? "selected='selected'": "").">$langQuestionDifficult</option>
-                        <option value='5' ".(isset($difficultyId) && $difficultyId == 5 ? "selected='selected'": "").">$langQuestionVeryDifficult</option>
-                    </select>
-                </div>
-                <div class='form-group mt-3'>
-                    <select onChange = 'document.qfilter.submit();' name='categoryId' class='form-select'>
-                        $q_cat_options
-                    </select>
-                </div>
-            </form>
-        </div>";
+                    </div>
+                    <div class='form-group mt-3'>
+                        <select onChange = 'document.qfilter.submit();' name='categoryId' class='form-select'>
+                            $q_cat_options
+                        </select>
+                    </div>
+                    <div class='form-group mt-3'>
+                        <select onChange = 'document.qfilter.submit();' name='difficultyId' class='form-select'>
+                            <option value='-1' ".(isset($difficultyId) && $difficultyId == -1 ? "selected='selected'": "").">-- $langQuestionAllDiffs --</option>
+                            <option value='0' ".(isset($difficultyId) && $difficultyId == 0 ? "selected='selected'": "").">-- $langQuestionNotDefined --</option>
+                            <option value='1' ".(isset($difficultyId) && $difficultyId == 1 ? "selected='selected'": "").">$langQuestionVeryEasy</option>
+                            <option value='2' ".(isset($difficultyId) && $difficultyId == 2 ? "selected='selected'": "").">$langQuestionEasy</option>
+                            <option value='3' ".(isset($difficultyId) && $difficultyId == 3 ? "selected='selected'": "").">$langQuestionModerate</option>
+                            <option value='4' ".(isset($difficultyId) && $difficultyId == 4 ? "selected='selected'": "").">$langQuestionDifficult</option>
+                            <option value='5' ".(isset($difficultyId) && $difficultyId == 5 ? "selected='selected'": "").">$langQuestionVeryDifficult</option>
+                        </select>
+                    </div>";
+                    $tool_content .= "<div class='form-group mt-3'>";
+                    $tool_content .= selection([
+                                                '-1' => "-- $langQuestionAllTypes --",
+                                                UNIQUE_ANSWER => $langUniqueSelect,
+                                                MULTIPLE_ANSWER => $langMultipleSelect,
+                                                TRUE_FALSE => $langTrueFalse,
+                                                FILL_IN_BLANKS_TOLERANT => $langFillBlanks,
+                                                FILL_IN_FROM_PREDEFINED_ANSWERS => $langFillFromSelectedWords,
+                                                MATCHING => $langMatching,
+                                                ORDERING => $langOrdering,
+                                                DRAG_AND_DROP_TEXT => $langDragAndDropText,
+                                                DRAG_AND_DROP_MARKERS => $langDragAndDropMarkers,
+                                                CALCULATED => $langCalculated,
+                                                FREE_TEXT => $langFreeText,
+                                                ORAL => $langOral,
+                                            ],
+                                        'answerType', $answerType, "onChange = 'document.qfilter.submit();'class='form-select'");
+                    $tool_content .= "</div>";
+            $tool_content .= "
+                </form>
+            </div>";
 //End of filtering Component
 
 if ($fromExercise) {
     $tool_content .= "<input type='hidden' name='fromExercise' value='$fromExercise'>";
 }
 
-$tool_content .= "<div class='table-responsive'><table class='table-default' id='questions'>";
+$tool_content .= "<div class='table-responsive'><table class='table-default' id='questions_$course_code'>";
 
 //START OF BUILDING QUERIES AND QUERY VARS
 if (isset($exerciseId) && $exerciseId > 0) { //If user selected specific exercise
     //Building query vars and query
     $result_query_vars = array($course_id, $exerciseId);
     $extraSql = "";
-    if(isset($difficultyId) && $difficultyId!=-1) {
+    if (isset($difficultyId) && $difficultyId!=-1) {
         $result_query_vars[] = $difficultyId;
         $extraSql .= " AND difficulty = ?d";
     }
-    if(isset($categoryId) && $categoryId!=-1) {
+    if (isset($categoryId) && $categoryId!=-1) {
         $result_query_vars[] = $categoryId;
         $extraSql .= " AND category = ?d";
     }
+
     if ($fromExercise) {
         $result_query_vars = array_merge($result_query_vars, [$fromExercise, $fromExercise]);
         $result_query = "SELECT exercise_question.id FROM `exercise_question` LEFT JOIN `exercise_with_questions`
@@ -351,17 +397,21 @@ if (isset($exerciseId) && $exerciseId > 0) { //If user selected specific exercis
                         WHERE course_id = ?d AND question_id = exercise_question.id AND exercise_id = ?d$extraSql
                         ORDER BY q_position";
     }
-} else { // if user selected either Orphan Question or All Questions
+} else { // question pool
     $result_query_vars[] = $course_id;
     $extraSql = "";
-    if(isset($difficultyId) && $difficultyId!=-1) {
+    if (isset($difficultyId) && $difficultyId!=-1) {
         $result_query_vars[] = $difficultyId;
         $extraSql .= " AND difficulty = ?d";
     }
-    if(isset($categoryId) && $categoryId!=-1) {
+    if (isset($categoryId) && $categoryId!=-1) {
         $result_query_vars[] = $categoryId;
         $extraSql .= " AND category = ?d";
     }
+    if (isset($answerType) && $answerType!=-1) {
+        $result_query_vars[] = $answerType;
+        $extraSql .= " AND type = ?d";
+    }
     // If user selected All question and comes to question pool from an exercise
     if ((!isset($exerciseId) || $exerciseId == 0) and $fromExercise) {
         $result_query_vars = array_merge($result_query_vars, [$fromExercise, $fromExercise]);
@@ -428,7 +478,7 @@ if (isset($_GET['exportIMSQTI'])) { // export to IMS QTI xml format
                 $question_excl_legend = '';
             }
             // check if question has answers
-            if ($question_type != FREE_TEXT and $question_type != MATCHING and (!$question_temp->hasAnswers())) {
+            if ($question_type != FREE_TEXT and $question_type != ORAL and $question_type != MATCHING and (!$question_temp->hasAnswers())) {
                 $question_excl_legend_2 = "&nbsp;&nbsp;<span class='fas fa-exclamation-triangle space-after-icon' 
                         data-bs-toggle='tooltip' data-bs-placement='right' data-bs-html='true' data-bs-title='$langNoQuestionAnswers'></span>";
             } else {
@@ -436,7 +486,7 @@ if (isset($_GET['exportIMSQTI'])) { // export to IMS QTI xml format
             }
             $tool_content .= "
                 <td>
-                  <div class='float-end fw-lighter text-heading-h6'>id: {$row->id}</></div>
+                  <div class='float-end fw-lighter text-heading-h6'>No: {$row->id}</></div>
                   <a class='$class' data-qid='{$row->id}' data-nbr='$nbr' data-editurl='$editUrl' href='admin.php?course=$course_code&amp;modifyAnswers={$row->id}&amp;fromExercise=$fromExercise'>$question_title</a>
                   $question_excl_legend<br>
                   <small>$question_type_legend $question_difficulty_legend $question_category_legend $question_excl_legend_2 $exercises_used_in</small>
