@@ -25,7 +25,8 @@ $helpTopic = 'forum';
 require_once '../../include/baseTheme.php';
 require_once 'include/log.class.php';
 require_once 'modules/group/group_functions.php';
-require_once 'modules/search/indexer.class.php';
+require_once 'modules/search/classes/ConstantsUtil.php';
+require_once 'modules/search/classes/SearchEngineFactory.php';
 require_once 'modules/forum/functions.php';
 
 $unit = isset($_GET['unit'])? intval($_GET['unit']): null;
@@ -41,6 +42,7 @@ if (!add_units_navigation(true)) {
 if ($is_editor) {
     load_js('tools.js');
 }
+load_js('datatables');
 
 $next = 0;
 if (isset($_GET['forum'])) {
@@ -110,64 +112,6 @@ if (isset($_GET['start'])) {
     $first_topic = 0;
 }
 
-if ($total_topics > TOPICS_PER_PAGE) { // navigation
-    $base_url = "$_SERVER[SCRIPT_NAME]?course=$course_code&amp;forum=$forum_id&amp;start=";
-    if ($unit) {
-        $base_url = "$_SERVER[SCRIPT_NAME]?course=$course_code&amp;res_type=forum&amp;unit=$unit&amp;forum=$forum_id&amp;start=";
-    }
-    $paging = array();
-
-    $current_page = $first_topic / TOPICS_PER_PAGE + 1; // current page
-    for ($x = 1; $x <= $pages; $x++) { // display navigation numbers
-        if ($current_page == $x) {
-            $paging[] = "<li class='active'><a href='#'>$x</a></li>";
-        } else {
-            $start = ($x - 1) * TOPICS_PER_PAGE;
-            $paging[] = "<li><a href='$base_url&amp;start=$start'>$x</a></li>";
-        }
-    }
-
-    $next = $first_topic + TOPICS_PER_PAGE;
-    $prev = $first_topic - TOPICS_PER_PAGE;
-    if ($prev < 0) {
-        $prev = 0;
-    }
-    if ($first_topic == 0) { // beginning
-        $nexturlclass = "";
-        $privurlclass = "class='disabled'";
-        $nexturl = $base_url.$next;
-        $prevurl = "#";
-    } elseif ($first_topic + TOPICS_PER_PAGE < $total_topics) {
-        $nexturlclass = "";
-        $privurlclass = "";
-        $prevurl = $base_url.$prev;
-        $nexturl = $base_url.$next;
-    } elseif ($start - TOPICS_PER_PAGE < $total_topics) { // end
-        $nexturlclass = "class='disabled'";
-        $privurlclass = "";
-        $nexturl = "#";
-        $prevurl = $base_url.$prev;
-    }
-
-    $tool_content .= "
-        <nav class='clearfix'>
-          <ul class='pagination float-end'>
-            <li $privurlclass>
-                <a href='$prevurl' aria-label='$langPrevious'>
-                    <span aria-hidden='true'>&laquo;</span>
-                </a>
-            </li>
-            ".implode($paging)."
-            <li $nexturlclass>
-              <a href='$nexturl' aria-label='$langNext'>
-                <span aria-hidden='true'>&raquo;</span>
-              </a>
-            </li>
-          </ul>
-        </nav>
-    ";
-}
-
 // delete topic
 if (($is_editor) and isset($_GET['topicdel'])) {
     if (isset($_GET['topic_id'])) {
@@ -212,14 +156,15 @@ if (($is_editor) and isset($_GET['topicdel'])) {
             Database::get()->query("INSERT INTO forum_user_stats (user_id, num_posts, course_id) VALUES (?d,?d,?d)", $author, $forum_user_stats->c, $course_id);
         }
     }
-    Indexer::queueAsync(Indexer::REQUEST_REMOVEBYTOPIC, Indexer::RESOURCE_FORUMPOST, $topic_id);
+    $searchEngine = SearchEngineFactory::create();
+    $searchEngine->indexResource(ConstantsUtil::REQUEST_REMOVEBYTOPIC, ConstantsUtil::RESOURCE_FORUMPOST, $topic_id);
     $number_of_topics = get_total_topics($forum_id);
     $num_topics = $number_of_topics - 1;
     if ($number_of_topics < 0) {
         $num_topics = 0;
     }
     Database::get()->query("DELETE FROM forum_topic WHERE id = ?d AND forum_id = ?d", $topic_id, $forum_id);
-    Indexer::queueAsync(Indexer::REQUEST_REMOVE, Indexer::RESOURCE_FORUMTOPIC, $topic_id);
+    $searchEngine->indexResource(ConstantsUtil::REQUEST_REMOVE, ConstantsUtil::RESOURCE_FORUMTOPIC, $topic_id);
 
     $last_post = Database::get()->querySingle("SELECT MAX(last_post_id) AS last_post FROM forum_topic WHERE forum_id = ?d", $forum_id)->last_post;
     if (!$last_post) {
@@ -243,13 +188,19 @@ if (isset($_GET['topicnotify'])) {
         $topic_id = intval($_GET['topic_id']);
     }
     $rows = Database::get()->querySingle("SELECT COUNT(*) AS count FROM forum_notify
-		WHERE user_id = ?d AND topic_id = ?d AND course_id = ?d", $uid, $topic_id, $course_id);
+        WHERE user_id = ?d AND topic_id = ?d AND course_id = ?d", $uid, $topic_id, $course_id);
     if ($rows->count > 0) {
         Database::get()->query("UPDATE forum_notify SET notify_sent = ?d
-			WHERE user_id = ?d AND topic_id = ?d AND course_id = ?d", $_GET['topicnotify'], $uid, $topic_id, $course_id);
+            WHERE user_id = ?d AND topic_id = ?d AND course_id = ?d", $_GET['topicnotify'], $uid, $topic_id, $course_id);
     } else {
         Database::get()->query("INSERT INTO forum_notify SET user_id = ?d,
-		topic_id = $topic_id, notify_sent = 1, course_id = ?d", $uid, $course_id);
+            topic_id = $topic_id, notify_sent = 1, course_id = ?d", $uid, $course_id);
+    }
+}
+
+if (isset($_GET['topicpin'])) {
+    if (isset($_GET['topic_id'])) {
+        $topic_id = intval($_GET['topic_id']);
     }
 }
 
@@ -268,16 +219,16 @@ if ($is_editor and isset($_GET['topiclock'])) {
 
 }
 
-$result = Database::get()->queryArray("SELECT t.*, p.post_time, t.poster_id AS topic_poster_id, p.poster_id AS poster_id
+$result = Database::get()->queryArray("SELECT t.*, p.post_time, t.poster_id AS topic_poster_id, p.poster_id AS poster_id, f.cat_id
         FROM forum_topic t
         LEFT JOIN forum_post p ON t.last_post_id = p.id
+        INNER JOIN forum f ON t.forum_id = f.id
         WHERE t.forum_id = ?d
-        ORDER BY topic_time DESC LIMIT $first_topic, " . TOPICS_PER_PAGE . "", $forum_id);
-
+        ORDER BY topic_time DESC", $forum_id);
 
 if (count($result) > 0) { // topics found
     $tool_content .= "<div class='table-responsive'>
-        <table class='table-default'>
+        <table class='table-default forum_viewforum'>
         <thead>
         <tr class='list-header'>
           <th class='forum_td'>$langTopics</th>
@@ -290,9 +241,12 @@ if (count($result) > 0) { // topics found
     foreach ($result as $myrow) {
         $replies = $myrow->num_replies;
         $topic_id = $myrow->id;
+        $forum_id = $myrow->forum_id;
+        $cat_id = $myrow->cat_id;
         $last_post_datetime = $myrow->post_time;
         $topic_title = $myrow->title;
         $topic_locked = $myrow->locked;
+
         $pagination = '';
         $topiclink = "viewtopic.php?course=$course_code&amp;topic=$topic_id&amp;forum=$forum_id";
         if ($unit) {
@@ -301,37 +255,50 @@ if (count($result) > 0) { // topics found
             $topiclink = "view.php?course=$course_code&amp;&amp;res_type=forum_topic&amp;topic=$topic_id&amp;forum=$forum_id";
         }
         if ($topic_locked) {
-            $image = icon('fa-lock');
+            $image_lock = icon('fa-lock');
         } else {
-            if ($replies >= HOT_THRESHOLD) {
-                $image = icon('fa-fire');
-            } else {
-                $image = icon('fa-comments');
-            }
+            $image_lock = '';
         }
-        if ($replies > POSTS_PER_PAGE) {
-            $total_reply_pages = ceil($replies / POSTS_PER_PAGE);
-            $pagination .= "<strong class='pagination'><span>&nbsp;".icon('fa-arrow-circle-right')." ";
-            add_topic_link(0, $total_reply_pages);
-            if ($total_reply_pages > PAGINATION_CONTEXT + 1) {
-                $pagination .= "&nbsp;...&nbsp;";
-            }
-            for ($p = max(1, $total_reply_pages - PAGINATION_CONTEXT); $p < $total_reply_pages; $p++) {
-                add_topic_link($p, $total_reply_pages);
-            }
-            $pagination .= "&nbsp;</span></strong>";
+
+        if ($replies >= HOT_THRESHOLD) {
+            $image_fire = icon('fa-fire');
+        } else {
+            $image_fire = '';
         }
-        $tool_content .= "<td>$image <a href='$topiclink'>" . q($topic_title) . "</a>$pagination</td>";
+
+//        $sql_notify = Database::get()->querySingle("SELECT notify_sent FROM forum_notify
+//			WHERE user_id = ?d AND topic_id = ?d AND course_id = ?d AND notify_sent = 1", $uid, $myrow->id, $course_id);
+
+        $sql_notify = Database::get()->queryArray("SELECT * FROM forum_notify
+			WHERE user_id = ?d
+			AND course_id = ?d
+			AND cat_id = ?d
+			OR forum_id = ?d
+			OR topic_id = ?d
+			order by topic_id DESC, forum_id DESC, cat_id DESC LIMIT 1", $uid, $course_id, $cat_id, $forum_id, $topic_id);
+
+        if ($sql_notify && $sql_notify[0]->notify_sent == 1) {
+            $notify_action = 1;
+            $image_notify = icon('fa-envelope');
+        } else {
+            $notify_action = 0;
+            $image_notify = '';
+        }
+
+        $tool_content .= "<td><div class='d-flex justify-content-between border-0'><a href='$topiclink'>" . q($topic_title) . "</a> <span class='d-flex align-items-center gap-2'>$image_lock $image_fire $image_notify</span></div></td>";
         $tool_content .= "<td>$replies</td>";
         $tool_content .= "<td>" . q(uid_to_name($myrow->topic_poster_id)) . "</td>";
         $tool_content .= "<td>$myrow->num_views</td>";
-        $tool_content .= "<td>";
         if (!is_null($last_post_datetime)) {
-            $tool_content .= "<br>" . format_locale_date(strtotime($last_post_datetime), 'short');
+//            $tool_content .= "<td data-order='$last_post_datetime'>";
+            $tool_content .= "<td>";
+            $tool_content .= format_locale_date(strtotime($last_post_datetime), 'short');
+        } else {
+            $tool_content .= "<td data-order='00/00/0000 - 00:00'>";
         }
         $tool_content .= "</td>";
         $sql = Database::get()->querySingle("SELECT notify_sent FROM forum_notify
-			WHERE user_id = ?d AND topic_id = ?d AND course_id = ?d", $uid, $myrow->id, $course_id);
+            WHERE user_id = ?d AND topic_id = ?d AND course_id = ?d", $uid, $myrow->id, $course_id);
         if ($sql) {
             $topic_action_notify = $sql->notify_sent;
         }
@@ -397,15 +364,58 @@ if (count($result) > 0) { // topics found
             }
         }
 
-
-        $dyntools[] = array('title' => $langNotify,
+        $dyntools[] = array('title' => $notify_action ? $langStopNotify : $langNotify,
                             'url' => $link_notify,
-                            'icon' => 'fa-envelope',
+                            'icon' => $notify_action ? 'fa-envelope-open' : 'fa-envelope',
                             'show' => (!setting_get(SETTING_COURSE_FORUM_NOTIFICATIONS)));
+
         $tool_content .= action_button($dyntools);
         $tool_content .= "</td></tr>";
     } // end of while
-    $tool_content .= "</table></div>";
+    $tool_content .= "</table>
+
+    <script>
+            $(document).ready(function() {
+                $('.table-default').DataTable({
+                    ordering: true,
+                    order: [],
+                    searching: true,
+                    columnDefs: [
+                        {
+                            targets: 0, // Enable searching only for the first column
+                            searchable: true
+                        },
+                        {
+                            targets: '_all', // Disable searching for all other columns
+                            searchable: false
+                        },
+                        {
+                            targets: -1, // No orderable for last column
+                            orderable: false
+                        }
+                    ],
+                    'searchDelay': 1000,
+                    'oLanguage': {
+                       'sLengthMenu':   '$langDisplay _MENU_ $langResults2',
+                       'sZeroRecords':  '" . $langNoResult . "',
+                       'sInfo':         '$langDisplayed _START_ $langTill _END_ $langFrom2 _TOTAL_ $langTotalResults',
+                       'sInfoEmpty':    '',
+                       'sInfoFiltered': '',
+                       'sInfoPostFix':  '',
+                       'sSearch':       '',
+                       'sUrl':          '',
+                       'oPaginate': {
+                           'sFirst':    '&laquo;',
+                           'sPrevious': '&lsaquo;',
+                           'sNext':     '&rsaquo;',
+                           'sLast':     '&raquo;'
+                       }
+                   }
+                });
+            });
+        </script>
+
+    </div>";
 } else {
     $tool_content .= "<div class='col-sm-12'><div class='alert alert-warning'><i class='fa-solid fa-triangle-exclamation fa-lg'></i><span>$langNoTopics</span></div></div>";
 }
