@@ -38,7 +38,8 @@ require_once 'modules/wiki/lib/class.wiki.php';
 require_once 'modules/wiki/lib/class.wikipage.php';
 require_once 'modules/wiki/lib/class.wikistore.php';
 /* ***Required classes for forum deletion*** */
-require_once 'modules/search/indexer.class.php';
+require_once 'modules/search/classes/ConstantsUtil.php';
+require_once 'modules/search/classes/SearchEngineFactory.php';
 /* * ** The following is added for statistics purposes ** */
 require_once 'include/action.php';
 $action = new action();
@@ -71,7 +72,17 @@ if (isset($_GET['urlview'])) {
     $urlview = '';
 }
 
+if(isset($_GET['show']) && $_GET['show'] == 'list') {
+    $_SESSION['group_show' . $course_id] = 'list';
+}
+
+if(isset($_GET['show']) && $_GET['show'] == 'card') {
+    $_SESSION['group_show' . $course_id] = 'card';
+}
+
+
 if ($is_editor) {
+    $searchEngine = SearchEngineFactory::create();
     if (isset($_GET['choice'])) { // change group visibility
         change_group_visibility($_GET['choice'], $_GET['group_id'], $course_id);
     }
@@ -300,13 +311,13 @@ if ($is_editor) {
                 foreach ($result2 as $result_row2) {
                     $topic_id = $result_row2->id;
                     Database::get()->query("DELETE FROM forum_post WHERE topic_id = ?d", $topic_id);
-                    Indexer::queueAsync(Indexer::REQUEST_REMOVEBYTOPIC, Indexer::RESOURCE_FORUMPOST, $topic_id);
+                    $searchEngine->indexResource(ConstantsUtil::REQUEST_REMOVEBYTOPIC, ConstantsUtil::RESOURCE_FORUMPOST, $topic_id);
                 }
                 Database::get()->query("DELETE FROM forum_topic WHERE forum_id = ?d", $forum_id);
-                Indexer::queueAsync(Indexer::REQUEST_REMOVEBYFORUM, Indexer::RESOURCE_FORUMTOPIC, $forum_id);
+                $searchEngine->indexResource(ConstantsUtil::REQUEST_REMOVEBYFORUM, ConstantsUtil::RESOURCE_FORUMTOPIC, $forum_id);
                 Database::get()->query("DELETE FROM forum_notify WHERE forum_id = ?d AND course_id = ?d", $forum_id, $course_id);
                 Database::get()->query("DELETE FROM forum WHERE id = ?d AND course_id = ?d", $forum_id, $course_id);
-                Indexer::queueAsync(Indexer::REQUEST_REMOVE, Indexer::RESOURCE_FORUM, $forum_id);
+                $searchEngine->indexResource(ConstantsUtil::REQUEST_REMOVE, ConstantsUtil::RESOURCE_FORUM, $forum_id);
             }
         }
         /*         * ******************************************** */
@@ -348,13 +359,13 @@ if ($is_editor) {
             foreach ($result2 as $result_row2) {
                 $topic_id = $result_row2->id;
                 Database::get()->query("DELETE FROM forum_post WHERE topic_id = ?d", $topic_id);
-                Indexer::queueAsync(Indexer::REQUEST_REMOVEBYTOPIC, Indexer::RESOURCE_FORUMPOST, $topic_id);
+                $searchEngine->indexResource(ConstantsUtil::REQUEST_REMOVEBYTOPIC, ConstantsUtil::RESOURCE_FORUMPOST, $topic_id);
             }
             Database::get()->query("DELETE FROM forum_topic WHERE forum_id = ?d", $forum_id);
-            Indexer::queueAsync(Indexer::REQUEST_REMOVEBYFORUM, Indexer::RESOURCE_FORUMTOPIC, $forum_id);
+            $searchEngine->indexResource(ConstantsUtil::REQUEST_REMOVEBYFORUM, ConstantsUtil::RESOURCE_FORUMTOPIC, $forum_id);
             Database::get()->query("DELETE FROM forum_notify WHERE forum_id = ?d AND course_id = ?d", $forum_id, $course_id);
             Database::get()->query("DELETE FROM forum WHERE id = ?d AND course_id = ?d", $forum_id, $course_id);
-            Indexer::queueAsync(Indexer::REQUEST_REMOVE, Indexer::RESOURCE_FORUM, $forum_id);
+            $searchEngine->indexResource(ConstantsUtil::REQUEST_REMOVE, ConstantsUtil::RESOURCE_FORUM, $forum_id);
         }
         /*         * *********************************** */
 
@@ -517,11 +528,12 @@ if ($is_editor) {
                 <tr><td class='not_visible nocategory-link'> - $langNoGroupInCategory - </td>
                 <td></td></tr></table></div></div></div>";
     } elseif ($num_of_groups > 0) {
-        if(isset($_GET['show']) && $_GET['show'] == 'list'){
-            //print_a($groupSelect);
+
+        if (isset($_SESSION['group_show' . $course_id]) && $_SESSION['group_show' . $course_id] == 'list') {
+
             // Here display the groups in a list
             $tool_content .= "<div class='col-12 mb-4'>
-                                <a class='btn submitAdminBtn d-inline-flex' href='{$urlAppend}modules/group/index.php?course={$course_code}'>$langFirstShow</a>
+                                <a class='btn submitAdminBtn d-inline-flex' href='{$urlAppend}modules/group/index.php?course={$course_code}&show=card'>$langFirstShow</a>
                             </div>";
             $tool_content .= "<div class='col-12'>
                 <div class='table-responsive'>
@@ -681,7 +693,7 @@ if ($is_editor) {
                                                                 $tool_content .= "<p class='form-label'>$langGroupTutor</p>";
                                                                 if(count($tutors)>0){
                                                                     foreach ($tutors as $t) {
-                                                                        $tool_content .= display_user($t->user_id) . "</br><div class='mt-2'></div>";
+                                                                        $tool_content .= display_user($t->user_id) . "<div class='mt-2'></div>";
                                                                     }
                                                                 }else{
                                                                     $tool_content .= "<p class='small-text'>$langNoInfoAvailable</p>";
@@ -830,9 +842,11 @@ if ($is_editor) {
                 <tr><td class='not_visible nocategory-link'> - $langNoGroupInCategory - </td>
                 </tr></table></div></div></div>";
     } else {
-        if(isset($_GET['show']) && $_GET['show'] == 'list'){
+
+        if (isset($_SESSION['group_show' . $course_id]) && $_SESSION['group_show' . $course_id] == 'list') {
+
             $tool_content .= "<div class='col-12 mb-4'>
-                                    <a class='btn submitAdminBtn d-inline-flex' href='{$urlAppend}modules/group/index.php?course={$course_code}'>$langFirstShow</a>
+                                    <a class='btn submitAdminBtn d-inline-flex' href='{$urlAppend}modules/group/index.php?course={$course_code}&show=card'>$langFirstShow</a>
                                 </div>";
             $tool_content .= "
                                 <div class='col-12'>
@@ -892,7 +906,7 @@ if ($is_editor) {
                                                                     $group_id_indirect = getIndirectReference($group_id);
                                                                     $control = '';
                                                                     if ($max_members == 0) {
-                                                                        $tool_content .= " <span class='badge Primary-600-bg'>$langGroupMembersNum:&nbsp; -- </span>";
+                                                                        $tool_content .= " <span class='badge Primary-600-bg'>$langGroupMembersNum:&nbsp;$member_count</span>";
                                                                     } else {
                                                                         $tool_content .= " <span class='badge Primary-600-bg'>$langGroupMembersNum:&nbsp;$member_count/$max_members</span>";
                                                                     };
@@ -967,7 +981,7 @@ if ($is_editor) {
                                                                     <p class='form-label'>$langGroupTutor</p>";
                                                                     if (count($tutors) > 0) {
                                                                         foreach ($tutors as $t) {
-                                                                            $tool_content .= display_user($t->user_id) . "</br><div class='mt-2'></div>";
+                                                                            $tool_content .= display_user($t->user_id) . "<div class='mt-2'></div>";
                                                                         }
                                                                     } else {
                                                                         $tool_content .= "<p class='small-text'>$langNoInfoAvailable</p>";
@@ -1011,7 +1025,7 @@ if ($is_editor) {
                                                                     }
                                                                     $tool_content .= ($control? $control: '&mdash;');
                                                                     if ($max_members == 0) {
-                                                                        $tool_content .= " <span class='badge Primary-600-bg'>$langGroupMembersNum:&nbsp; -- </span>";
+                                                                        $tool_content .= " <span class='badge Primary-600-bg'>$langGroupMembersNum:&nbsp;$member_count</span>";
                                                                     } else {
                                                                         $tool_content .= " <span class='badge Primary-600-bg'>$langGroupMembersNum:&nbsp;$member_count/$max_members</span>";
                                                                     }
