@@ -1,5 +1,22 @@
 <?php
 
+/*
+ *  ========================================================================
+ *  * Open eClass
+ *  * E-learning and Course Management System
+ *  * ========================================================================
+ *  * Copyright 2003-2024, Greek Universities Network - GUnet
+ *  *
+ *  * Open eClass is an open platform distributed in the hope that it will
+ *  * be useful (without any warranty), under the terms of the GNU (General
+ *  * Public License) as published by the Free Software Foundation.
+ *  * The full license can be read in "/info/license/license_gpl.txt".
+ *  *
+ *  * Contact address: GUnet Asynchronous eLearning Group
+ *  *                  e-mail: info@openeclass.org
+ *  * ========================================================================
+ *
+ */
 /*
  *  ========================================================================
  *  * Open eClass
@@ -89,11 +106,12 @@ if (isset($_GET['id'])) {
     }
 }
 
-if (isset($_GET['per_user']) or isset($_GET['u'])) { // all users participation in meetings
+if (isset($_GET['per_user']) or isset($_GET['u'])) { // all-users participation in meetings
     if (!$is_course_reviewer and isset($_GET['per_user'])) { // security check
         redirect_to_home_page();
     }
-    if (isset($_GET['u']) and $_GET['u']) { // participation for specific user
+
+    if (isset($_GET['u']) and $_GET['u']) { // participation for a specific user
         if (!$is_course_reviewer and $_GET['u'] != $_SESSION['uid']) { // security check
             redirect_to_home_page();
         }
@@ -101,7 +119,9 @@ if (isset($_GET['per_user']) or isset($_GET['u'])) { // all users participation
         $bbb_name = uid_to_name($u, 'username');
 
         if (isset($_GET['xls'])) {
-            $data[] = [ get_config('site_name') . " - " . q($currentCourseName) . " - " . q($langParticipate) ];
+            $data[] = [ get_config('site_name') . " - " . q($currentCourseName) ];
+            $data[] = [ q($langStatsReport) ];
+            $data[] = [];
         }
 
         $result = Database::get()->queryArray("SELECT title, start_date, meetingid, bbbuserid, totaltime, date FROM tc_attendance, tc_session 
@@ -115,32 +135,45 @@ if (isset($_GET['per_user']) or isset($_GET['u'])) { // all users participation
                                                     AND tc_session.course_id = ?d 
                                                     AND tc_attendance.bbbuserid = ?s", $course_id, $bbb_name)->totaltime;
         if (count($result) > 0) {
+            $ug_string = '';
+            $ug = user_groups($course_id, $u, 'txt');
+            if ($ug != '-') {
+                $ug_string = " - $ug";
+            }
             $tool_content .= "<div class='panel panel-default'>";
-            $tool_content .= "<div class='panel-heading'><strong>" . q(uid_to_name($u, 'surname')) . " " . q(uid_to_name($u, 'givenname')) . "</strong></div>";
+            $tool_content .= "<div class='panel-heading'><strong>" . q(uid_to_name($u, 'surname')) . " " . q(uid_to_name($u, 'givenname')) . " " . $ug_string . "</strong></div>";
             $tool_content .= "<div class='panel-body'><em>$langTotalDuration:</em> <strong>" . format_time_duration(0 + 60 * $total_time, 24, false) . "</strong></span></div><br>";
             $tool_content .= "</div>";
             if (isset($_GET['xls'])) {
-                $data[] = [ uid_to_name($u, 'surname') . " " . uid_to_name($u, 'givenname') .  " -- $langTotalDuration: " . format_time_duration(0 + 60 * $total_time, 24, false) ];
+                $data[] = [ uid_to_name($u, 'surname') . " " . uid_to_name($u, 'givenname') .  " " . $ug_string . " -- $langTotalDuration: " . format_time_duration(0 + 60 * $total_time, 24, false) ];
             }
             $data[] = [];
 
             $tool_content .= "<div class='table-responsive'><table class='table-default'>";
             $tool_content .= "<thead><tr class='list-header'>
-                              <th>$langBBB</th>
-                              <th>$langLogIn</th>
-                              <th>$langDuration</th>
+                              <th>$langBBB</th>";
+            if (isset($_GET['pdf'])) {
+                $tool_content .= "<th>$langDate</th>";
+            } else {
+                $tool_content .= "<th>$langLogIn</th>";
+            }
+            $tool_content .= "<th>$langDuration</th>
                            </tr></thead>";
             if (isset($_GET['xls'])) {
-                $data[] = [$langBBB, $langLogIn, $langDuration];
+                $data[] = [$langBBB, $langDate, $langDuration];
             }
             foreach ($result as $row) {
-                $tool_content .= "<tr>
-                        <td>$row->title</td>
-                        <td>" . format_locale_date(strtotime($row->date), 'full') . "</td>
-                        <td>" . format_time_duration(0 + 60 * $row->totaltime, 24, false) . "</td>
-                    </tr>";
+                $tool_content .= "<tr>";
+                $tool_content .= "<td>$row->title</td>";
+                if (isset($_GET['pdf'])) {
+                    $tool_content .= "<td>" . format_locale_date(strtotime($row->date), 'full', false) . "</td>";
+                } else {
+                    $tool_content .= "<td>" . format_locale_date(strtotime($row->date), 'full') . "</td>";
+                }
+                $tool_content .= "<td>" . format_time_duration(0 + 60 * $row->totaltime, 24, false) . "</td>";
+                $tool_content .= "</tr>";
                 if (isset($_GET['xls'])) {
-                    $data[] = [ $row->title, format_locale_date(strtotime($row->date), 'full'), format_time_duration(0 + 60 * $row->totaltime, 24, false)];
+                    $data[] = [ $row->title, format_locale_date(strtotime($row->date), 'full', false), format_time_duration(0 + 60 * $row->totaltime, 24, false)];
                 }
             }
             $tool_content .= "</table></div>";
@@ -159,8 +192,8 @@ if (isset($_GET['per_user']) or isset($_GET['u'])) { // all users participation
                     </tr></thead>";
 
         if (isset($_GET['xls'])) {
-            $data[] = [ get_config('site_name') . " - " . q($currentCourseName) . " - " . q($langParticipate) ];
-            $data[] = [];
+            $data[] = [ get_config('site_name') . " - " . q($currentCourseName) ];
+            $data[] = [ q($langStatsReport) ];
             $data[] = [];
             $data[] = [ $langSurnameName , $langAm, $langGroup, $langTotalDuration ];
         }
@@ -185,7 +218,7 @@ if (isset($_GET['per_user']) or isset($_GET['u'])) { // all users participation
             }
 
             $tool_content .= "<tr>                            
-                        <td>$user->surname $user->givenname</td>
+                        <td>"  . q($user->surname) . " " .q($user->givenname) . "</td>
                         <td>$user->am</td>
                         <td>" . $grp_name . "</td>                            
                         <td>" . format_time_duration(0 + 60 * $result->totaltime, 24, false) . "</td>
@@ -221,10 +254,10 @@ if (isset($_GET['per_user']) or isset($_GET['u'])) { // all users participation
     if (count($result) > 0) {
 
         if (isset($_GET['xls'])) {
-            $data[] = [ get_config('site_name') . " - " . q($currentCourseName) . " - " . q($langParticipate) ];
+            $data[] = [ get_config('site_name') . " - " . q($currentCourseName) ];
+            $data[] = [ q($langStatsReport) ];
             $data[] = [];
-            $data[] = [];
-            $data[] = [ $langSurnameName, $langBBB, $langLogIn, $langTotalDuration ];
+            $data[] = [ $langSurnameName, $langBBB, $langDate, $langTotalDuration ];
         }
         $tool_content .= "<div class='table-responsive'><table class='table-default'>";
         $temp_date = null;
@@ -237,9 +270,13 @@ if (isset($_GET['per_user']) or isset($_GET['u'])) { // all users participation
                 $tool_content .= "<tr><td colspan='4' class='list-header text-left'><strong>$row->title</strong></td></tr>";
                 $tool_content .= "<thead><tr class='list-header'>
                                   <th class='ps-3'>$langSurnameName</th>
-                                  <th>$langBBB</th>
-                                  <th>$langLogIn</th>
-                                  <th>$langTotalDuration</th>
+                                  <th>$langBBB</th>";
+               if (isset($_GET['pdf'])) {
+                   $tool_content .= "<th>$langDate</th>";
+               } else {
+                   $tool_content .= "<th>$langLogIn</th>";
+               }
+               $tool_content .= "<th>$langTotalDuration</th>
                                </tr></thead>";
                 $temp_date = $row->start_date;
                 $first = false;
@@ -247,12 +284,16 @@ if (isset($_GET['per_user']) or isset($_GET['u'])) { // all users participation
             $user_full_name = Database::get()->querySingle("SELECT fullName FROM tc_log
                             WHERE tc_log.bbbuserid = ?s ORDER BY id DESC LIMIT 1", $row->bbbuserid)->fullName;
             $tool_content .= "<tr><td>$user_full_name</td>                            
-                            <td>$row->title</td>
-                            <td>" . format_locale_date(strtotime($row->date), 'full') . "</td>
-                            <td>" . format_time_duration(0 + 60 * $row->totaltime, 24, false) . "</td>
+                            <td>$row->title</td>";
+            if (isset($_GET['pdf'])) {
+                $tool_content .= "<td>" . format_locale_date(strtotime($row->date), 'full', false) . "</td>";
+            } else {
+                $tool_content .= "<td>" . format_locale_date(strtotime($row->date), 'full') . "</td>";
+            }
+            $tool_content .= "<td>" . format_time_duration(0 + 60 * $row->totaltime, 24, false) . "</td>
                             </tr>";
             if (isset($_GET['xls'])) {
-                $data[] = [ $user_full_name, $row->title, format_locale_date(strtotime($row->date), 'full'), format_time_duration(0 + 60 * $row->totaltime, 24, false) ];
+                $data[] = [ $user_full_name, $row->title, format_locale_date(strtotime($row->date), 'full', false), format_time_duration(0 + 60 * $row->totaltime, 24, false) ];
             }
         }
         $tool_content .= "</table></div>";
@@ -269,7 +310,7 @@ if (isset($_GET['pdf']) and $is_course_reviewer) {
         <html lang='el'>
         <head>
           <meta charset='utf-8'>
-          <title>" . q("$currentCourseName - $langParticipate") . "</title>
+          <title>" . q("$currentCourseName - $langStatsReport") . "</title>
           <style>
             * { font-family: 'opensans'; }
             body { font-family: 'opensans'; font-size: 10pt; }
@@ -282,8 +323,10 @@ if (isset($_GET['pdf']) and $is_course_reviewer) {
             td { text-align: left; }
           </style>
         </head>
-        <body>" . get_platform_logo() .
-        "<h2> " . get_config('site_name') . " - " . q($currentCourseName) . " - " . q($langParticipate) . "</h2><p></p>";
+        <body>
+        <h2> " . get_config('site_name') . " - " . q($currentCourseName) . "</h2>
+         <h3>" . q($langStatsReport) . "</h3>
+         <p></p>";
 
     $pdf_content .= $tool_content;
     $pdf_content .= "</body></html>";
@@ -294,6 +337,8 @@ if (isset($_GET['pdf']) and $is_course_reviewer) {
     $fontData = $defaultFontConfig['fontdata'];
 
     $mpdf = new Mpdf\Mpdf([
+        'margin_top' => 53,     // approx 200px
+        'margin_bottom' => 53,  // approx 200px
         'tempDir' => _MPDF_TEMP_PATH,
         'fontDir' => array_merge($fontDirs, [ $webDir . '/template/modern/fonts' ]),
         'fontdata' => $fontData + [
@@ -310,7 +355,19 @@ if (isset($_GET['pdf']) and $is_course_reviewer) {
             ]
     ]);
 
-    $mpdf->setFooter('{DATE j-n-Y} || {PAGENO} / {nb}');
+   
+    $mpdf->SetHTMLHeader(get_platform_logo());
+    $footerHtml = '
+    <div>
+        <table width="100%" style="border: none;">
+            <tr>
+                <td style="text-align: left;">{DATE j-n-Y}</td>
+                <td style="text-align: right;">{PAGENO} / {nb}</td>
+            </tr>
+        </table>
+    </div>
+    ' . get_platform_logo('','footer') . '';
+    $mpdf->SetHTMLFooter($footerHtml);
     $mpdf->SetCreator(course_id_to_prof($course_id));
     $mpdf->SetAuthor(course_id_to_prof($course_id));
     $mpdf->WriteHTML($pdf_content);
@@ -334,7 +391,6 @@ if (isset($_GET['pdf']) and $is_course_reviewer) {
     set_content_disposition('attachment', $filename);
     $writer->save("php://output");
     exit;
-
-}else {
+} else {
     draw($tool_content, 2, null, $head_content);
 }
