@@ -86,18 +86,20 @@
 
             <div class='col-lg-6 col-12 mt-4'>
                 <div class='row row-cols-1 row-cols-lg-2 g-4'>
-                    <div class='col'>
-                        <div class='card panelCard h-100'>
-                            <div class='card-body d-flex justify-content-center align-items-center'>
-                                <div>
-                                    <h1 class='d-flex justify-content-center align-items-center'>
-                                        <i class='fa-solid fa-user pe-2'></i>{{ getOnlineUsers() }}
-                                    </h1>
-                                    <div class='form-label text-center'>{{ trans('langOnlineUsers') }}</div>
+                    @if ($onlineusers > 0)
+                        <div class='col'>
+                            <div class='card panelCard h-100'>
+                                <div class='card-body d-flex justify-content-center align-items-center'>
+                                    <div>
+                                        <h1 class='d-flex justify-content-center align-items-center'>
+                                            <i class='fa-solid fa-user pe-2'></i>{{ $onlineusers }}
+                                        </h1>
+                                        <div class='form-label text-center'>{{ trans('langOnlineUsers') }}</div>
+                                    </div>
                                 </div>
                             </div>
                         </div>
-                    </div>
+                    @endif
                     <div class='col'>
                         <div class='card panelCard h-100'>
                             <div class='card-body d-flex justify-content-center align-items-center'>
@@ -158,36 +160,98 @@
                             </div>
                         </div>
 
-                        <div class='col'>
-                            <div class='card panelCard border-card-left-default px-lg-4 py-lg-3 h-100'>
-                                <div class='card-body'>
-                                    <div class='row p-2 margin-bottom-thin'>
-                                        <div class='col-lg-6 col-12'>
-                                            <div class='form-label'>{{ trans('langIndexNumDocs') }}</div>
-                                        </div>
-                                        <div class='col-lg-6 col-12'>
-                                            <div>{{ $numDocs }}</div>
-                                        </div>
-                                    </div>
-                                    <div class='row p-2 margin-bottom-thin'>
-                                        <div class='col-lg-6 col-12'>
-                                            <div class='form-label'>{{ trans('langIndexIsOptimized') }}</div>
-                                        </div>
-                                        <div class='col-lg-6 col-12'>
-                                            <div>{{ $isOpt }}</div>
-                                        </div>
-                                    </div>
-                                    <div class='row p-2 margin-bottom-thin'>
-                                        <div class='d-flex justify-content-start align-items-center gap-3 flex-wrap'>
-                                            <a class='btn submitAdminBtn text-nowrap' href='../search/optpopup.php' onclick="return optpopup('../search/optpopup.php', 600, 500)">{{ trans('langOptimize') }}</a>
-                                            <a class='btn submitAdminBtn text-nowrap mt-lg-0 mt-3' id='reindex_link' href='../search/idxpopup.php?reindex'>{{ trans('langReindex') }}</a>
-                                        </div>
+                        @if (get_config('ext_solr_enabled') && !empty($coreStats))
+                            <div class='col'>
+                                <div class='card panelCard border-card-left-default px-lg-4 py-lg-3 h-100'>
+                                    <div class='card-body'>
+                                        @if (get_config('enable_indexing'))
+                                            <div class='row p-2 margin-bottom-thin'>
+                                                <div class='col-lg-6 col-12'>
+                                                    <div class='form-label'>{{ trans('langIndexNumDocs') }}</div>
+                                                </div>
+                                                <div class='col-lg-6 col-12'>
+                                                    <div>{{ $coreStats['numDocs'] }}</div>
+                                                </div>
+                                            </div>
+                                            <div class='row p-2 margin-bottom-thin'>
+                                                <div class='col-lg-6 col-12'>
+                                                    <div class='form-label'>{{ trans('langLastUpdate') }}</div>
+                                                </div>
+                                                <div class='col-lg-6 col-12'>
+                                                    <div>{!! format_locale_date((new DateTime($coreStats['lastModified']))->getTimestamp()) !!}</div>
+                                                </div>
+                                            </div>
+                                            <div class='row p-2 margin-bottom-thin'>
+                                                <div class='col-lg-6 col-12'>
+                                                    <div class='form-label'>{{ trans('langSize') }}</div>
+                                                </div>
+                                                <div class='col-lg-6 col-12'>
+                                                    <div>{{ $coreStats['size'] }}</div>
+                                                </div>
+                                            </div>
+                                            <div class='row p-2 margin-bottom-thin'>
+                                                <div class='d-flex justify-content-start align-items-center gap-3 flex-wrap'>
+                                                    <a class='btn submitAdminBtn text-nowrap mt-lg-0 mt-3' id='reindex_link' href='../search/idxpopup.php?reindex'>{{ trans('langReindex') }}</a>
+                                                </div>
+                                            </div>
+                                        @else
+                                            <div class='row p-2'>
+                                                <div class='col-lg-6 col-12'>
+                                                    <div class='form-label'>{{ trans('langMetaIndex') }}</div>
+                                                </div>
+                                                <div class='col-lg-6 col-12'>
+                                                    {{ trans('langIndexDisabled') }}
+                                                </div>
+                                            </div>
+                                        @endif
                                     </div>
                                 </div>
+                                {!! $idxModal !!}
+                                <img src='cron.php' width='2' height='1' alt=''>
                             </div>
-                            {!! $idxModal !!}
-                            <img src='cron.php' width='2' height='1' alt=''>
-                        </div>
+                        @elseif (get_config('enable_indexing'))
+                            <div class='col'>
+                                <div class='card panelCard border-card-left-default px-lg-4 py-lg-3 h-100'>
+                                    <div class='card-body'>
+                                        @if (get_config('enable_indexing'))
+                                            <div class='row p-2 margin-bottom-thin'>
+                                                <div class='col-lg-6 col-12'>
+                                                    <div class='form-label'>{{ trans('langIndexNumDocs') }}</div>
+                                                </div>
+                                                <div class='col-lg-6 col-12'>
+                                                    <div>{{ $numDocs }}</div>
+                                                </div>
+                                            </div>
+                                            <div class='row p-2 margin-bottom-thin'>
+                                                <div class='col-lg-6 col-12'>
+                                                    <div class='form-label'>{{ trans('langIndexIsOptimized') }}</div>
+                                                </div>
+                                                <div class='col-lg-6 col-12'>
+                                                    <div>{{ $isOpt }}</div>
+                                                </div>
+                                            </div>
+                                            <div class='row p-2 margin-bottom-thin'>
+                                                <div class='d-flex justify-content-start align-items-center gap-3 flex-wrap'>
+                                                    <a class='btn submitAdminBtn text-nowrap' href='../search/optpopup.php' onclick="return optpopup('../search/optpopup.php', 600, 500)">{{ trans('langOptimize') }}</a>
+                                                    <a class='btn submitAdminBtn text-nowrap mt-lg-0 mt-3' id='reindex_link' href='../search/idxpopup.php?reindex'>{{ trans('langReindex') }}</a>
+                                                </div>
+                                            </div>
+                                        @else
+                                            <div class='row p-2'>
+                                                <div class='col-lg-6 col-12'>
+                                                    <div class='form-label'>{{ trans('langMetaIndex') }}</div>
+                                                </div>
+                                                <div class='col-lg-6 col-12'>
+                                                    {{ trans('langIndexDisabled') }}
+                                                </div>
+                                            </div>
+                                        @endif
+                                    </div>
+                                </div>
+                                {!! $idxModal !!}
+                                <img src='cron.php' width='2' height='1' alt=''>
+                            </div>
+                        @endif
                     </div>
                 </div>
 
