@@ -7,6 +7,40 @@
 
             @include('layouts.partials.show_alert')
 
+            @if (Session::has('login_error'))
+                <div class='modal show' id='warning-modal' tabindex='0'>
+                    <div class='modal-dialog modal-dialog-centered'>
+                        <div class='modal-content border-0 p-0'>
+                            <div class='modal-header d-flex justify-content-between align-items-center'>
+                                <h2 class='modal-title'>{{ trans('langError') }}</h2>
+                                <button aria-label="{{ trans('langClose') }}" type='button' class='close' data-bs-dismiss='modal' id="closeBtn"></button>
+                            </div>
+                            <div class='modal-body'>
+                                <div class='alert alert-warning'>
+                                    <i class='fa-solid fa-triangle-exclamation fa-lg'></i>
+                                    <span>{!! Session::get('login_error') !!}</span>
+                                </div>
+                            </div>
+                        </div>
+                    </div>
+                </div>
+                @push('bottom_scripts')
+                    <script>
+                        var warningModal = new bootstrap.Modal(document.getElementById('warning-modal'), {});
+                        const focusTarget = document.getElementById('closeBtn');
+                        warningModal.show();
+                        document.getElementById('warning-modal').addEventListener('shown.bs.modal', function () {
+                            focusTarget.focus();
+                        });
+                        document.body.addEventListener('keydown', function(e) {
+                          if (e.key == "Escape") {
+                            warningModal.hide();
+                          }
+                        });
+                    </script>
+                @endpush
+            @endif
+
             <div class='row m-auto'>
                 <h1>{{ trans('langUserLogin') }}</h1>
                 <div class='padding-default mt-4'>
@@ -20,38 +54,13 @@
                                                 <div class='col-12 container-pages d-flex align-items-center h-100'>
 
                                                     @foreach($authLink as $authInfo)
-
-                                                        @if (Session::has('login_error') and $authInfo[0])
-                                                            <div class='col-12'>
-                                                                <input id='showWarningModal2' type='hidden' value='1'>
-                                                                <div class='modal fade' id='WarningModal2' aria-hidden='true' tabindex='-1' data-bs-backdrop='static' data-bs-keyboard='false'>
-                                                                    <div class='modal-dialog modal-dialog-centered'>
-                                                                        <div class='modal-content border-0 p-0'>
-                                                                            <div class='modal-header d-flex justify-content-between align-items-center'>
-                                                                                <div class='modal-title'>{{ trans('langError') }}</div>
-                                                                                <button aria-label="{{ trans('langClose') }}" type='button' class='close close-error' data-bs-dismiss='modal'></button>
-                                                                            </div>
-                                                                            <div class='modal-body'>
-                                                                                <div class='alert alert-warning'>
-                                                                                    <i class='fa-solid fa-triangle-exclamation fa-lg'></i>
-                                                                                    <span>{!! Session::get('login_error') !!}</span>
-                                                                                </div>
-                                                                            </div>
-                                                                        </div>
-                                                                    </div>
-                                                                </div>
-                                                            </div>
-                                                        @endif
-
                                                         @if ($loop->first)
                                                             <div class='col-12 page slide-page h-100'>
                                                         @else
                                                             @if ($primary_method >= 2 && count($authLink) == 2)
                                                                 @break
                                                             @endif
-
                                                             <div class='col-12 page next-page-{{ $loop->iteration-1 }} h-100'>
-
                                                         @endif
 
                                                         <div class='row h-100'>
@@ -94,10 +103,33 @@
                                                                     <div id='or' class='ms-auto me-auto mb-2' >
                                                                         {{ trans('langOr') }}
                                                                     </div>
-                                                                    <div class='d-flex gap-3 flex-wrap'>
+                                                                    <div class='d-flex justify-content-between align-items-center flex-wrap gap-2'>
                                                                         <h2 class='mb-3'>
                                                                             {{ $authLink[1][2] }}
                                                                         </h2>
+                                                                        @if (!empty($authLink[1][3])) {{-- Optional auth instructions --}}
+                                                                            <a href='#' class='text-decoration-underline mb-3' data-bs-toggle='modal' data-bs-target='#authInstruction{{ $loop->index+1 }}'>
+                                                                                {{ trans('langInstructionsAuth') }}
+                                                                            </a>
+                                                                            <div class='modal fade' id='authInstruction{{ $loop->index+1 }}' tabindex='-1' role='dialog' aria-labelledby='authInstructionLabel' aria-hidden='true'>
+                                                                                <div class='modal-dialog'>
+                                                                                    <div class='modal-content'>
+                                                                                        <div class='modal-header'>
+                                                                                            <div class='modal-title' id='authInstructionLabel'>{{ trans('langInstructionsAuth') }}</div>
+                                                                                            <button type='button' class='close' data-bs-dismiss='modal' aria-label="{{ trans('langClose') }}"></button>
+                                                                                        </div>
+                                                                                        <div class='modal-body'>
+                                                                                            <div class='col-12'>
+                                                                                                <div class='alert alert-info'>
+                                                                                                    <i class='fa-solid fa-circle-info fa-lg'></i>
+                                                                                                    <span>{{ $authLink[1][3] }}</span>
+                                                                                                </div>
+                                                                                            </div>
+                                                                                        </div>
+                                                                                    </div>
+                                                                                </div>
+                                                                            </div>
+                                                                        @endif
                                                                         {!! $authLink[1][1] !!}
                                                                     </div>
                                                                 @elseif (count($authLink) > 2)
@@ -192,14 +224,6 @@
 
 <script type='text/javascript'>
     $(document).ready(function() {
-        if($('#showWarningModal2').val() == 1){
-            var ModalWarning = document.getElementById('WarningModal2');
-            var Modal_W = new bootstrap.Modal(ModalWarning);
-            Modal_W.show();
-        }
-        $('.close-error').on('click',function(){
-            window.location.reload();
-        });
         $('#revealPass').mousedown(function () {
             $('#password_id').attr('type', 'text');
         }).mouseup(function () {
