@@ -6,106 +6,198 @@
 @endpush
 
 @push('head_scripts')
-<script type='text/javascript' src='{{ $urlAppend }}js/jstree3/jstree.min.js'></script>
-<script type='text/javascript' src='{{ $urlAppend }}js/pwstrength.js'></script>
-<script type='text/javascript' src='{{ $urlAppend }}js/tools.js'></script>
+    <script type='text/javascript' src='{{ $urlAppend }}js/jstree3/jstree.min.js'></script>
+    <script type='text/javascript' src='{{ $urlAppend }}js/pwstrength.js'></script>
+    <script type='text/javascript' src='{{ $urlAppend }}js/tools.js'></script>
 
-<script type='text/javascript'>
+    <script type='text/javascript'>
+        var lang = {
+            pwStrengthTooShort: "{{ js_escape(trans('langPwStrengTooShort')) }}",
+            pwStrengthWeak: "{{ js_escape(trans('langPwStrengthWeak')) }}",
+            pwStrengthGood: "{{ js_escape(trans('langPwStrengthGood')) }}",
+            pwStrengthStrong: "{{ js_escape(trans('langPwStrengthStrong')) }}"
+        }
 
-    function deactivate_input_password () {
-            $('#coursepassword').attr('disabled', 'disabled');
+        function deactivate_input_password () {
+            $('#coursepassword, #faculty_users_registration').attr('disabled', 'disabled');
             $('#coursepassword').closest('div.form-group').addClass('invisible');
-    }
+        }
 
-    function activate_input_password () {
-            $('#coursepassword').removeAttr('disabled', 'disabled');
+        function activate_input_password () {
+            $('#coursepassword, #faculty_users_registration').removeAttr('disabled', 'disabled');
             $('#coursepassword').closest('div.form-group').removeClass('invisible');
-    }
+        }
 
-    function displayCoursePassword() {
-
-            if ($('#courseclose,#courseiactive').is(":checked")) {
-                    deactivate_input_password ();
+        function displayCoursePassword() {
+            if ($('#courseclose, #courseiactive').is(":checked")) {
+                deactivate_input_password ();
             } else {
-                    activate_input_password ();
-            }
-    }
-
-    var lang = {
-        pwStrengthTooShort: "{{ js_escape(trans('langPwStrengTooShort')) }}",
-        pwStrengthWeak: "{{ js_escape(trans('langPwStrengthWeak')) }}",
-        pwStrengthGood: "{{ js_escape(trans('langPwStrengthGood')) }}",
-        pwStrengthStrong: "{{ js_escape(trans('langPwStrengthStrong')) }}"
-    }
-
-    function showCCFields() {
-        $('#cc').show();
-    }
-    function hideCCFields() {
-        $('#cc').hide();
-    }
-
-    $(document).ready(function() {
-
-        $('#coursepassword').keyup(function() {
-            $('#result').html(checkStrength($('#coursepassword').val()))
-        });
-
-        displayCoursePassword();
-
-        $('#courseopen').click(function(event) {
-                activate_input_password();
-        });
-        $('#coursewithregistration').click(function(event) {
-                activate_input_password();
-        });
-        $('#courseclose').click(function(event) {
-                deactivate_input_password();
-        });
-        $('#courseinactive').click(function(event) {
-                deactivate_input_password();
-        });
-
-        $('input[name=l_radio]').change(function () {
-            if ($('#cc_license').is(":checked")) {
-                showCCFields();
-            } else {
-                hideCCFields();
-            }
-        }).change();
-
-        if($("#radio_collaborative_helper").length > 0){
-            if(document.getElementById("radio_collaborative_helper").value == 0){
-                document.getElementById("radio_collaborative").style.display="none";
-            }else{
-                document.getElementById("radio_collaborative").style.display="block";
+                activate_input_password ();
             }
         }
-        if($('#type_collab').is(":checked")){
-            document.getElementById("radio_flippedclassroom").style.display="none";
-            document.getElementById("radio_activity").style.display="none";
-            document.getElementById("radio_wall").style.display="none";
-        }else{
-            document.getElementById("radio_flippedclassroom").style.display="block";
-            document.getElementById("radio_activity").style.display="block";
-            document.getElementById("radio_wall").style.display="block";
-        }
-        $('#type_collab').on('click',function(){
-            if($('#type_collab').is(":checked")){
+
+        $(document).ready(function() {
+
+            $('#coursepassword').keyup(function() {
+                $('#result').html(checkStrength($('#coursepassword').val()))
+            });
+
+            displayCoursePassword();
+
+            $('#courseopen').click(function(event) {
+                activate_input_password();
+            });
+            $('#coursewithregistration').click(function(event) {
+                activate_input_password();
+            });
+            $('#courseclose').click(function(event) {
+                deactivate_input_password();
+            });
+            $('#courseinactive').click(function(event) {
+                deactivate_input_password();
+            });
+
+            $('input[name=l_radio]').change(function () {
+                if ($('#cc_license').is(":checked")) {
+                    $('#cc').show();
+                } else {
+                    $('#cc').hide();
+                }
+            }).change();
+
+            if ($("#radio_collaborative_helper").length > 0) {
+                if (document.getElementById("radio_collaborative_helper").value == 0) {
+                    document.getElementById("radio_collaborative").style.display="none";
+                } else {
+                    document.getElementById("radio_collaborative").style.display="block";
+                }
+            }
+            if ($('#type_collab').is(":checked")) {
                 document.getElementById("radio_flippedclassroom").style.display="none";
                 document.getElementById("radio_activity").style.display="none";
                 document.getElementById("radio_wall").style.display="none";
-                document.getElementById("radio_collaborative").style.display="block";
-            }else{
+            } else {
                 document.getElementById("radio_flippedclassroom").style.display="block";
                 document.getElementById("radio_activity").style.display="block";
                 document.getElementById("radio_wall").style.display="block";
-                document.getElementById("radio_collaborative").style.display="none";
             }
-        });
-    });
+            $('#type_collab').on('click',function() {
+                if($('#type_collab').is(":checked")) {
+                    document.getElementById("radio_flippedclassroom").style.display="none";
+                    document.getElementById("radio_activity").style.display="none";
+                    document.getElementById("radio_wall").style.display="none";
+                    document.getElementById("radio_collaborative").style.display="block";
+                }else{
+                    document.getElementById("radio_flippedclassroom").style.display="block";
+                    document.getElementById("radio_activity").style.display="block";
+                    document.getElementById("radio_wall").style.display="block";
+                    document.getElementById("radio_collaborative").style.display="none";
+                }
+            });
 
-</script>
+            // Print Header Images functionality
+            $('#loadPrintHeaderImages').click(function() {
+                loadPrintImages('header');
+            });
+
+            // Print Footer Images functionality
+            $('#loadPrintFooterImages').click(function() {
+                loadPrintImages('footer');
+            });
+
+            function loadPrintImages(type) {
+                const modalId = type === 'header' ? '#PrintHeaderImagesModal' : '#PrintFooterImagesModal';
+                const contentId = type === 'header' ? '#printHeaderImagesContent' : '#printFooterImagesContent';
+
+                $(contentId).html('<div class="text-center"><i class="fa fa-spinner fa-spin"></i> Loading images...</div>');
+
+                $.ajax({
+                    url: '{{ $urlAppend }}modules/course_info/ajax_load_images.php',
+                    method: 'GET',
+                    data: {
+                        course_id: '{{ $course_id ?? "" }}',
+                        type: type
+                    },
+                    dataType: 'json',
+                    success: function(response) {
+                        if (response.success && response.images) {
+                            displayImages(response.images, type, contentId);
+                        } else {
+                            $(contentId).html('<div class="alert alert-info">{{ trans("langNoImagesFound") }}</div>');
+                        }
+                    },
+                    error: function(xhr, status, error) {
+                        console.error('Error loading images:', error);
+                        $(contentId).html('<div class="alert alert-danger">Error loading images. Please try again.</div>');
+                    }
+                });
+            }
+
+            function displayImages(images, type, contentId) {
+                let html = '<div class="row">';
+
+                images.forEach(function(image) {
+                    html += `
+                        <div class="col-md-3 col-sm-4 col-6 mb-3">
+                            <div class="card print-image-card" style="cursor: pointer;" data-image-path="${image.path}" data-image-name="${image.name}" data-type="${type}" data-image-id="${image.id}">
+                                <img src="${image.url}" class="card-img-top" style="height: 150px; object-fit: cover;" alt="${image.name}">
+                                <div class="card-body p-2">
+                                    <small class="text-muted">${image.name}</small>
+                                </div>
+                            </div>
+                        </div>
+                    `;
+                });
+
+                html += '</div>';
+                $(contentId).html(html);
+
+                // Handle image selection
+                $(contentId).on('click', '.print-image-card', function() {
+                    const imagePath = $(this).data('image-path');
+                    const imageName = $(this).data('image-name');
+                    const imageType = $(this).data('type');
+                    const imageID = $(this).data('image-id');
+
+                    // Remove previous selection styling
+                    $(contentId).find('.print-image-card').removeClass('border-primary');
+
+                    // Add selection styling
+                    $(this).addClass('border-primary');
+
+                    // Update hidden input and display
+                    if (imageType === 'header') {
+                        $('#choose_print_header_from_list').val(imageID);
+                        $('#selectedPrintHeaderImage').html(`<small class="text-success"><i class="fa fa-check"></i> Selected: ${imageName}</small>`);
+                    } else {
+                        $('#choose_print_footer_from_list').val(imageID);
+                        $('#selectedPrintFooterImage').html(`<small class="text-success"><i class="fa fa-check"></i> Selected: ${imageName}</small>`);
+                    }
+
+                    // Close modal after selection
+                    setTimeout(function() {
+                        $(imageType === 'header' ? '#PrintHeaderImagesModal' : '#PrintFooterImagesModal').modal('hide');
+                    }, 500);
+                });
+            }
+
+            // Delete Print Header Image
+            $('#deletePrintHeaderImage').click(function() {
+                $('#choose_print_header_from_list').val('0');
+                $('#printHeaderImagePreview').remove();
+                $('#selectedPrintHeaderImage').html('');
+            });
+
+            // Delete Print Footer Image
+            $('#deletePrintFooterImage').click(function() {
+                $('#choose_print_footer_from_list').val('0');
+                $('#printFooterImagePreview').remove();
+                $('#selectedPrintFooterImage').html('');
+            });
+
+        });
+
+    </script>
 @endpush
 
 @section('content')
@@ -342,8 +434,13 @@
                                         </div>
                                     </div>
 
-
-                                    <div class='form-group mt-4'>
+                                    <div class='form-group mt-3'>
+                                        <div class='checkbox mb-2 mt-4'>
+                                            <label class='label-container' aria-label="{{ trans('langSelect') }}">
+                                                <input type='checkbox' id='faculty_users_registration' name='faculty_users_registration' {!! $check_enable_faculty_users_registration !!}>
+                                                <span class='checkmark'></span>{{ trans('langFacultyUsersRegistrationLegend') }}
+                                            </label>
+                                        </div>
                                         <label for='coursepassword' class='col-sm-12 control-label-notes'>{{ trans('langOptPassword') }}</label>
                                         <div class='col-sm-12'>
                                               <input class='form-control' id='coursepassword' type='text' name='password' value='{{ $password }}' autocomplete='off'>
@@ -440,9 +537,6 @@
                                         </div>
                                     </div>
 
-
-
-
                                     <div class='form-group mt-4'>
                                         <div class='col-sm-12 control-label-notes mb-2'>{{ trans('langForum') }}</div>
                                         <div class='col-sm-12'>
@@ -461,9 +555,6 @@
                                         </div>
                                     </div>
 
-
-
-
                                     <div class='form-group mt-4'>
                                         <div class='col-sm-12 control-label-notes mb-2'>{{ trans('langCourseRating') }}:</div>
                                         <div class='col-sm-12'>
@@ -482,8 +573,6 @@
                                         </div>
                                     </div>
 
-
-
                                     <div class='form-group mt-4'>
                                         <div class='col-sm-12 control-label-notes mb-2'>{{ trans('langCourseAnonymousRating') }}</div>
                                         <div class='col-sm-12'>
@@ -504,9 +593,6 @@
                                         </div>
                                     </div>
 
-
-
-
                                     <div class='form-group mt-4'>
                                         <div class='col-sm-12 control-label-notes mb-2'>{{ trans('langCourseCommenting') }}</div>
                                         <div class='col-sm-12'>
@@ -525,6 +611,24 @@
                                         </div>
                                     </div>
 
+                                    <div class='form-group mt-4'>
+                                        <div class='col-sm-12 control-label-notes mb-2'>{{ trans('langH5PUploadingEnabled') }}</div>
+                                        <div class='col-sm-12'>
+                                            <div class='radio mb-2'>
+                                                <label>
+                                                    <input type='radio' value='1' name='h5p_radio' {!! $checkH5PEn !!}>
+                                                    {{ trans('langActivate') }}
+                                                </label>
+                                            </div>
+                                            <div class='radio'>
+                                                <label>
+                                                    <input type='radio' value='0' name='h5p_radio' {!! $checkH5PDis !!}>
+                                                    {{ trans('langDeactivate') }}
+                                                </label>
+                                            </div>
+                                        </div>
+                                    </div>
+
                                     <div class='form-group mt-4'>
                                         <div class='col-sm-12 control-label-notes mb-2'>{{ trans('langAbuseReport') }}</div>
                                         <div class='col-sm-12'>
@@ -542,6 +646,119 @@
                                             </div>
                                         </div>
                                     </div>
+
+                                    @if (get_config('enable_docs_public_write'))
+                                    <div class='form-group mt-4'>
+                                        <div class='col-sm-12 control-label-notes mb-2'>{{ trans('langEnableDocsPublicWrite') }}</div>
+                                        <div class='col-sm-12'>
+                                            <div class='radio'>
+                                                <label>
+                                                    <input type='radio' value='1' name='docs_public_write'
+                                                        @if (setting_get(SETTING_DOCUMENTS_PUBLIC_WRITE)) checked @endif>
+                                                    {{ trans('langPublicDocumentManagementExplanation') }}
+                                                </label>
+                                            </div>
+                                            <div class='radio'>
+                                                <label>
+                                                    <input type='radio' value='0' name='docs_public_write'
+                                                        @if (!setting_get(SETTING_DOCUMENTS_PUBLIC_WRITE)) checked @endif>
+                                                    {{ trans('langDeactivate') }}
+                                                </label>
+                                            </div>
+                                        </div>
+                                    </div>
+                                    @endif
+
+                                    <div class='form-group mt-4'>
+                                        <div class='col-sm-12 control-label-notes mb-2'>{{ trans('langDisplayRightContentInCPage') }}</div>
+                                        <div class='col-sm-12'>
+                                            <div class='radio'>
+                                                <label>
+                                                    <input type='radio' value='1' name='enable_agenda_announcement_widget_courseCompletion' {!! $check_enable_agenda_announcement_widget_courseCompletion !!}>
+                                                    {{ trans('langActivate') }}
+                                                </label>
+                                            </div>
+                                            <div class='radio'>
+                                                <label>
+                                                    <input type='radio' value='0' name='enable_agenda_announcement_widget_courseCompletion' {!! $check_disable_agenda_announcement_widget_courseCompletion !!} >
+                                                    {{ trans('langDeactivate') }}
+                                                </label>
+                                            </div>
+                                        </div>
+                                    </div>
+
+                                    @php
+                                        $print_header_image_url = setting_get_print_image_url(SETTING_COUSE_IMAGE_PRINT_HEADER, $course_id);
+                                        $print_footer_image_url = setting_get_print_image_url(SETTING_COUSE_IMAGE_PRINT_FOOTER, $course_id);
+                                    @endphp
+
+                                    <div class='form-group mt-4'>
+                                        <h3>{{ trans('langCoursePrintSetting') }}</h3>
+                                        <div class='col-sm-12 control-label-notes mt-3'>
+                                            {{ trans('langCoursePrintHeaderImage') }}
+                                            <span class="ms-2"><small>{{ trans('langReportImageNotFound') }}</small></span>
+                                            @if($print_header_image_url)
+                                                <div class="mt-2" id="printHeaderImagePreview">
+                                                    <img src="{{ $print_header_image_url }}" alt="Print Header Image" style="max-width: 200px; max-height: 100px;" class="img-thumbnail">
+                                                </div>
+                                            @endif
+                                            <div class="d-flex gap-2 align-items-center mt-2">
+                                                <button type="button" class="btn btn-secondary" id="loadPrintHeaderImages" data-bs-toggle="modal" data-bs-target="#PrintHeaderImagesModal">
+                                                    <i class="fa fa-images"></i> {{ trans('langSelectFromGallery') }}
+                                                </button>
+                                                <button type="button" class="btn deleteAdminBtn btn-sm" id="deletePrintHeaderImage">
+                                                    <i class="fa fa-trash"></i>
+                                                </button>
+                                            </div>
+                                            <div class="d-flex gap-2 align-items-center mt-2">
+                                                <label class="col-sm-2" for="header_image_alignment">{{ trans('langAlignment') }}</label>
+                                                <select name="header_image_alignment" id="header_image_alignment" class="form-select">
+                                                    <option value="0" {{ setting_get(SETTING_COUSE_IMAGE_PRINT_HEADER_ALIGNMENT, $course_id) == '0' ? 'selected' : '' }}>{{ trans('langAlignLeft') }}</option>
+                                                    <option value="1" {{ setting_get(SETTING_COUSE_IMAGE_PRINT_HEADER_ALIGNMENT, $course_id) == '1' ? 'selected' : '' }}>{{ trans('langAlignCenter') }}</option>
+                                                    <option value="2" {{ setting_get(SETTING_COUSE_IMAGE_PRINT_HEADER_ALIGNMENT, $course_id) == '2' ? 'selected' : '' }}>{{ trans('langAlignRight') }}</option>
+                                                </select>
+                                            </div>
+                                            <div class="d-flex gap-2 align-items-center mt-2">
+                                                <label class="col-sm-2" for="header_image_width">{{ trans('langWidth') }} (px)</label>
+                                                <input type="number" name="header_image_width" id="header_image_width" value="{{ setting_get(SETTING_COUSE_IMAGE_PRINT_HEADER_WIDTH, $course_id) }}" placeholder="Width (px)" class="form-control">
+                                            </div>
+                                            <input type="hidden" name="choose_print_header_from_list" id="choose_print_header_from_list" value="{{ $print_header_image_url ? setting_get(SETTING_COUSE_IMAGE_PRINT_HEADER, $course_id) : '' }}">
+                                            <div id="selectedPrintHeaderImage" class="mt-2 text-muted"></div>
+                                        </div>
+
+                                        <div class='col-sm-12 control-label-notes mt-3'>
+                                            {{ trans('langCoursePrintFooterImage') }}
+                                            <span class="ms-2"><small>{{ trans('langReportImageNotFound') }}</small></span>
+                                            @if($print_footer_image_url)
+                                                <div class="mt-2" id="printFooterImagePreview">
+                                                    <img src="{{ $print_footer_image_url }}" alt="Print Footer Image" style="max-width: 200px; max-height: 100px;" class="img-thumbnail">
+                                                </div>
+                                            @endif
+                                            <div class="d-flex gap-2 align-items-center mt-2">
+                                                <button type="button" class="btn btn-secondary" id="loadPrintFooterImages" data-bs-toggle="modal" data-bs-target="#PrintFooterImagesModal">
+                                                    <i class="fa fa-images"></i> {{ trans('langSelectFromGallery') }}
+                                                </button>
+                                                <button type="button" class="btn deleteAdminBtn btn-sm" id="deletePrintFooterImage">
+                                                    <i class="fa fa-trash"></i>
+                                                </button>
+                                            </div>
+                                            <div class="d-flex gap-2 align-items-center mt-2">
+                                                <label class="col-sm-2" for="header_image_alignment">{{ trans('langAlignment') }}</label>
+                                                <select name="footer_image_alignment" id="footer_image_alignment" class="form-select">
+                                                    <option value="0" {{ setting_get(SETTING_COUSE_IMAGE_PRINT_FOOTER_ALIGNMENT, $course_id) == '0' ? 'selected' : '' }}>{{ trans('langAlignLeft') }}</option>
+                                                    <option value="1" {{ setting_get(SETTING_COUSE_IMAGE_PRINT_FOOTER_ALIGNMENT, $course_id) == '1' ? 'selected' : '' }}>{{ trans('langAlignCenter') }}</option>
+                                                    <option value="2" {{ setting_get(SETTING_COUSE_IMAGE_PRINT_FOOTER_ALIGNMENT, $course_id) == '2' ? 'selected' : '' }}>{{ trans('langAlignRight') }}</option>
+                                                </select>
+                                            </div>
+                                            <div class="d-flex gap-2 align-items-center mt-2">
+                                                <label class="col-sm-2" for="header_image_width">{{ trans('langWidth') }} (px)</label>
+                                                <input type="number" name="footer_image_width" id="footer_image_width" value="{{ setting_get(SETTING_COUSE_IMAGE_PRINT_FOOTER_WIDTH, $course_id) }}" placeholder="Width (px)" class="form-control">
+                                            </div>
+                                            <input type="hidden" name="choose_print_footer_from_list" id="choose_print_footer_from_list" value="{{ $print_footer_image_url ? setting_get(SETTING_COUSE_IMAGE_PRINT_FOOTER, $course_id) : '' }}">
+                                            <div id="selectedPrintFooterImage" class="mt-2 text-muted"></div>
+                                        </div>
+                                    </div>
+
                                     {!! showSecondFactorChallenge() !!}
 
                                     <div class='form-group mt-5 mb-1 d-flex justify-content-end align-items-center'>
@@ -563,4 +780,39 @@
 
 </div>
 </div>
+
+<!-- Print Images Modal -->
+<div class="modal fade" id="PrintHeaderImagesModal" tabindex="-1" aria-labelledby="PrintHeaderImagesModalLabel" aria-hidden="true">
+    <div class="modal-dialog modal-xl">
+        <div class="modal-content">
+            <div class="modal-header">
+                <h5 class="modal-title" id="PrintHeaderImagesModalLabel">{{ trans('langCoursePrintHeaderImage') }}</h5>
+                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
+            </div>
+            <div class="modal-body">
+                <div id="printHeaderImagesContent">
+                    <!-- Images will be loaded here via AJAX -->
+                </div>
+            </div>
+        </div>
+    </div>
+</div>
+
+<!-- Print Footer Images Modal -->
+<div class="modal fade" id="PrintFooterImagesModal" tabindex="-1" aria-labelledby="PrintFooterImagesModalLabel" aria-hidden="true">
+    <div class="modal-dialog modal-xl">
+        <div class="modal-content">
+            <div class="modal-header">
+                <h5 class="modal-title" id="PrintFooterImagesModalLabel">{{ trans('langCoursePrintFooterImage') }}</h5>
+                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
+            </div>
+            <div class="modal-body">
+                <div id="printFooterImagesContent">
+                    <!-- Images will be loaded here via AJAX -->
+                </div>
+            </div>
+        </div>
+    </div>
+</div>
+
 @endsection
