@@ -72,6 +72,7 @@
                     file_copyrighted: fileCopyrighted,
                     replace: replace,
                     uncompress: uncompress,
+                    token: '{{ $_SESSION['csrf_token'] }}'
                 });
 
                 uppy.use(XHRUpload, {
@@ -89,6 +90,7 @@
                         'file_copyrighted',
                         'replace',
                         'uncompress',
+                        'token'
                     ],
                     shouldRetry: () => false,
                 })
@@ -99,12 +101,11 @@
                 });
 
                 uppy.on('file-added', (file) => {
-                    console.log('File added:', file)
+                  //  console.log('File added:', file)
                 })
 
                 uppy.on('complete', (result) => {
                     window.location.href = '{!! $backUrl !!}';
-
                 })
                 isUppyLoaded = true;
             } catch (error) {
@@ -299,7 +300,7 @@
                             {!! $metaDataBox !!}
                         </div>
                     @endif
-                    @if ($can_upload)
+                    @if ($can_upload or $user_upload)
                         <div class="col-12 drag_and_drop_container d-none mb-3">
                             <input type="hidden" name="uploadPath" value="{{ $curDirPath }}">
                             <input type='hidden' name='file_creator' value='{{ $_SESSION['givenname'] . ' ' . $_SESSION['surname'] }}' size='40'>
@@ -588,7 +589,7 @@
         e.preventDefault();
         var fileURL = $(this).attr('href');
         var downloadURL = $(this).closest('tr').find('input[type=hidden]').first().val();
-        var fileTitle = $(this).attr('title');
+        var fileTitle = q($(this).attr('title'));
 
         // BUTTONS declare
         var bts = {
